@@ -2,11 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-
-#ifndef __ICAL_RECURRENCE_H
-#define __ICAL_RECURRENCE_H
-
-#include <kopano/zcdefs.h>
+#pragma once
 #include "recurrence.h"
 #include "vtimezone.h"
 #include "icalitem.h"
@@ -18,7 +14,7 @@ namespace KC {
 /**
  * Conversion class for recurrence & exceptions (mapi <-> ical)
  */
-class ICalRecurrence _kc_final {
+class ICalRecurrence final {
 public:
 	/* ical -> mapi */
 	HRESULT HrParseICalRecurrenceRule(const TIMEZONE_STRUCT &, icalcomponent *root_event, icalcomponent *event, bool all_day, const SPropTagArray *named_props, icalitem *);
@@ -36,5 +32,3 @@ private:
 };
 
 } /* namespace */
-
-#endif
