@@ -2,9 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-#ifndef __INETMAPI_OPTIONS_H
-#define __INETMAPI_OPTIONS_H
-
+#pragma once
 #include <kopano/zcdefs.h>
 #include <map>
 #include <string>
@@ -46,9 +44,7 @@ struct sending_options {
 	bool always_expand_distr_list, ignore_missing_attachments;
 };
 
-extern _kc_export void imopt_default_delivery_options(delivery_options *);
-extern _kc_export void imopt_default_sending_options(sending_options *);
+extern KC_EXPORT void imopt_default_delivery_options(delivery_options *);
+extern KC_EXPORT void imopt_default_sending_options(sending_options *);
 
 } /* namespace */
-
-#endif
