@@ -2,10 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-
-#ifndef ECCONFIG_H
-#define ECCONFIG_H
-
+#pragma once
 #include <kopano/zcdefs.h>
 #include <list>
 #include <string>
@@ -29,28 +26,26 @@ struct configsetting_t {
 
 static const char *const lpszDEFAULTDIRECTIVES[] = {"include", NULL};
 
-class _kc_export ECConfig {
+class KC_EXPORT ECConfig {
 public:
 	static ECConfig *Create(const configsetting_t *defaults, const char *const *directives = lpszDEFAULTDIRECTIVES);
 	static ECConfig *Create(const std::nothrow_t &, const configsetting_t *defaults, const char *const *directives = lpszDEFAULTDIRECTIVES);
 	static const char *GetDefaultPath(const char *basename);
-	_kc_hidden virtual ~ECConfig(void) = default;
-	_kc_hidden virtual bool LoadSettings(const char *file, bool ignore_missing = false) = 0;
-	_kc_hidden virtual int ParseParams(int argc, char **argv) = 0;
-	_kc_hidden virtual const char *GetSettingsPath() const = 0;
-	_kc_hidden virtual bool	ReloadSettings(void) = 0;
-	_kc_hidden virtual bool	AddSetting(const char *name, const char *value, unsigned int group = 0) = 0;
-	_kc_hidden virtual const char *GetSetting(const char *name) = 0;
-	_kc_hidden virtual const char *GetSetting(const char *name, const char *equal, const char *other) = 0;
-	_kc_hidden virtual std::list<configsetting_t> GetSettingGroup(unsigned int group) = 0;
-	_kc_hidden virtual std::list<configsetting_t> GetAllSettings(void) = 0;
-	_kc_hidden virtual bool	HasWarnings(void) = 0;
-	_kc_hidden virtual const std::list<std::string> *GetWarnings(void) = 0;
-	_kc_hidden virtual bool	HasErrors(void) = 0;
-	_kc_hidden virtual const std::list<std::string> *GetErrors(void) = 0;
-	_kc_hidden virtual int dump_config(FILE *) = 0;
+	KC_HIDDEN virtual ~ECConfig() = default;
+	KC_HIDDEN virtual bool LoadSettings(const char *file, bool ignore_missing = false) = 0;
+	KC_HIDDEN virtual int ParseParams(int argc, char **argv) = 0;
+	KC_HIDDEN virtual const char *GetSettingsPath() const = 0;
+	KC_HIDDEN virtual bool	ReloadSettings() = 0;
+	KC_HIDDEN virtual bool	AddSetting(const char *name, const char *value, unsigned int group = 0) = 0;
+	KC_HIDDEN virtual const char *GetSetting(const char *name) = 0;
+	KC_HIDDEN virtual const char *GetSetting(const char *name, const char *equal, const char *other) = 0;
+	KC_HIDDEN virtual std::list<configsetting_t> GetSettingGroup(unsigned int group) = 0;
+	KC_HIDDEN virtual std::list<configsetting_t> GetAllSettings() = 0;
+	KC_HIDDEN virtual bool HasWarnings() = 0;
+	KC_HIDDEN virtual const std::list<std::string> *GetWarnings() = 0;
+	KC_HIDDEN virtual bool	HasErrors() = 0;
+	KC_HIDDEN virtual const std::list<std::string> *GetErrors() = 0;
+	KC_HIDDEN virtual int dump_config(FILE *) = 0;
 };
 
 } /* namespace */
-
-#endif // ECCONFIG_H
