@@ -2,9 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-#ifndef ECSCHEDULER_H
-#define ECSCHEDULER_H
-
+#pragma once
 #include <kopano/zcdefs.h>
 #include <condition_variable>
 #include <mutex>
@@ -33,15 +31,15 @@ struct ECSCHEDULE {
 
 typedef std::list<ECSCHEDULE> ECScheduleList;
 
-class _kc_export ECScheduler KC_FINAL {
+class KC_EXPORT ECScheduler KC_FINAL {
 public:
 	ECScheduler();
 	~ECScheduler(void);
 	HRESULT AddSchedule(eSchedulerType eType, unsigned int ulBeginCycle, void* (*lpFunction)(void*), void* lpData = NULL);
 
 private:
-	_kc_hidden static bool hasExpired(time_t ttime, ECSCHEDULE *);
-	_kc_hidden static void *ScheduleThread(void *tmp_scheduler);
+	KC_HIDDEN static bool hasExpired(time_t, ECSCHEDULE *);
+	KC_HIDDEN static void *ScheduleThread(void *tmp_scheduler);
 
 	ECScheduleList		m_listScheduler;
 	bool m_thread_active = false, m_bExit = false;
@@ -52,5 +50,3 @@ private:
 };
 
 } /* namespace */
-
-#endif
