@@ -2,9 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-
-#ifndef ECTAGS_H
-#define ECTAGS_H
+#pragma once
 
 /*
  * Inside MAPI, p.38: private range for service providers (6600-67ff)
@@ -92,7 +90,6 @@
 #define PR_EC_STATS_SESSION_CAPABILITY		PROP_TAG(PT_LONG, 0x6745)
 #define PR_EC_STATS_SESSION_LOCKED		PROP_TAG(PT_BOOLEAN, 0x6746)
 #define PR_EC_STATS_SESSION_BUSYSTATES		PROP_TAG(PT_MV_STRING8, 0x6747)
-#define PR_EC_STATS_SESSION_PORT		PROP_TAG(PT_LONG, 0x6748)
 #define PR_EC_STATS_SESSION_PROCSTATES		PROP_TAG(PT_MV_STRING8, 0x6749)
 
 /* currently only used in user stats table */
@@ -108,11 +105,9 @@
 #define PR_EC_STATS_SESSION_CPU_REAL		PROP_TAG(PT_DOUBLE, 0x674C)
 
 #define PR_EC_STATS_SESSION_GROUP_ID		PROP_TAG(PT_LONGLONG, 0x674D)
-#define PR_EC_STATS_SESSION_PEER_PID		PROP_TAG(PT_LONG, 0x674E)
 #define PR_EC_STATS_SESSION_CLIENT_VERSION	PROP_TAG(PT_STRING8, 0x674F)
 #define PR_EC_STATS_SESSION_CLIENT_APPLICATION	PROP_TAG(PT_STRING8, 0x6750)
 #define PR_EC_STATS_SESSION_REQUESTS		PROP_TAG(PT_LONG, 0x6751)
-#define PR_EC_STATS_SESSION_URL			PROP_TAG(PT_STRING8, 0x6752)
 #define PR_EC_STATS_SESSION_PROXY		PROP_TAG(PT_STRING8, 0x6753)
 #define PR_EC_STATS_SESSION_CLIENT_APPLICATION_VERSION	PROP_TAG(PT_STRING8, 0x6754)
 #define PR_EC_STATS_SESSION_CLIENT_APPLICATION_MISC	PROP_TAG(PT_STRING8, 0x6755)
@@ -292,5 +287,3 @@
 // Extra table flag, do not let the server cap contents on 255 characters
 // 1 bit under the MAPI_UNICODE bit, hopefully we won't clash with Exchange bits later on
 #define EC_TABLE_NOCAP			0x40000000
-
-#endif
