@@ -2,9 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-#ifndef ECThreadPool_INCLUDED
-#define ECThreadPool_INCLUDED
-
+#pragma once
 #include <atomic>
 #include <condition_variable>
 #include <map>
@@ -22,7 +20,7 @@ class ECTask;
 class ECThreadPool;
 class ECWatchdog;
 
-class _kc_export ECThreadWorker {
+class KC_EXPORT ECThreadWorker {
 	public:
 	ECThreadWorker(ECThreadPool *);
 	virtual ~ECThreadWorker() {}
@@ -37,7 +35,7 @@ class _kc_export ECThreadWorker {
  * The amount of workers can be modified at run time, but is not automatically
  * adjusted based on the task queue length or age.
  */
-class _kc_export ECThreadPool {
+class KC_EXPORT ECThreadPool {
 	protected:
 	struct STaskInfo {
 		ECTask			*lpTask;
@@ -52,7 +50,7 @@ public:
 	ECThreadPool(const std::string &name, unsigned int spares);
 	virtual ~ECThreadPool();
 	void enable_watchdog(bool, std::shared_ptr<ECConfig> = {});
-	bool enqueue(ECTask *lpTask, bool bTakeOwnership = false);
+	bool enqueue(ECTask *lpTask, bool bTakeOwnership = false, time_point *enq_time = nullptr);
 	void set_thread_count(unsigned int spares, unsigned int tmax = 0, bool wait = false);
 	void add_extra_thread();
 	time_duration front_item_age() const;
@@ -63,11 +61,11 @@ public:
 
 	protected:
 	virtual std::unique_ptr<ECThreadWorker> make_worker();
-	_kc_hidden size_t threadCount() const; /* unlocked variant */
-	_kc_hidden bool getNextTask(STaskInfo *, std::unique_lock<std::mutex> &);
-	_kc_hidden void joinTerminated(std::unique_lock<std::mutex> &);
-	_kc_hidden HRESULT create_thread_unlocked();
-	_kc_hidden static void *threadFunc(void *);
+	KC_HIDDEN size_t threadCount() const; /* unlocked variant */
+	KC_HIDDEN bool getNextTask(STaskInfo *, std::unique_lock<std::mutex> &);
+	KC_HIDDEN void joinTerminated(std::unique_lock<std::mutex> &);
+	KC_HIDDEN HRESULT create_thread_unlocked();
+	KC_HIDDEN static void *threadFunc(void *);
 
 	ThreadSet m_setThreads, m_setTerminated;
 	TaskList	m_listTasks;
@@ -91,7 +89,7 @@ public:
  * executed.
  * There is no way of knowing when the task is done.
  */
-class _kc_export ECTask {
+class KC_EXPORT ECTask {
 public:
 	virtual ~ECTask(void) = default;
 	virtual void execute(void);
@@ -128,7 +126,7 @@ inline bool ECTask::queue_on(ECThreadPool *p, bool own)
  * derived object. It's similar to an ECTask, but one can wait for the task
  * to be finished.
  */
-class _kc_export ECWaitableTask : public ECTask {
+class KC_EXPORT ECWaitableTask : public ECTask {
 public:
 	static const unsigned WAIT_INFINITE = (unsigned)-1;
 
@@ -139,7 +137,7 @@ public:
 	};
 
 	virtual ~ECWaitableTask();
-	virtual void execute(void) _kc_override;
+	virtual void execute() override;
 	bool done() const { return m_state == Done; }
 	bool wait(unsigned timeout = WAIT_INFINITE, unsigned waitMask = Done) const;
 
@@ -168,10 +166,7 @@ public:
 	ECDeferredFunc(Fn fn, const At &arg) : m_fn(fn), m_arg(arg)
 	{ }
 
-	virtual void run(void) _kc_override
-	{
-		m_result = m_fn(m_arg);
-	}
+	virtual void run() override { m_result = m_fn(m_arg); }
 
 	/**
 	 * Get the result of the asynchronous function. This method will
@@ -190,5 +185,3 @@ private:
 };
 
 } /* namespace */
-
-#endif // ndef ECThreadPool_INCLUDED
