@@ -2,10 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-
-#ifndef RECURRENCESTATE_H
-#define RECURRENCESTATE_H
-
+#pragma once
 #include <kopano/zcdefs.h>
 #include <vector>
 #include <string>
@@ -66,48 +63,37 @@ namespace KC {
 #define PT_HJ_MONTH_NTH		0xB
 #define PT_HJ_MONTH_END		0xC
 
-class _kc_export RecurrenceState KC_FINAL {
+class KC_EXPORT RecurrenceState KC_FINAL {
 	public:
 	HRESULT ParseBlob(const char *lpData, size_t ulLen, ULONG ulFlags);
 	HRESULT GetBlob(char **lpData, size_t *lpulLen, void *base = NULL);
 
-	class _kc_hidden Exception KC_FINAL {
+	private:
+	HRESULT ParseBlob2(const char *data, size_t len, unsigned int flags, bool &readvalid, bool &ext);
+
+	public:
+	class KC_HIDDEN Exception KC_FINAL {
 		public:
-		unsigned int ulStartDateTime;
-		unsigned int ulEndDateTime;
-		unsigned int ulOriginalStartDate;
-		unsigned int ulOverrideFlags;
-		std::string strSubject;
-		unsigned int ulApptStateFlags;
-		unsigned int ulReminderDelta;
-		unsigned int ulReminderSet;
-		std::string strLocation;
-		unsigned int ulBusyStatus;
-		unsigned int ulAttachment;
-		unsigned int ulSubType;
-		unsigned int ulAppointmentColor;
+		std::string strSubject, strLocation;
+		unsigned int ulStartDateTime = 0, ulEndDateTime = 0;
+		unsigned int ulOriginalStartDate = 0, ulOverrideFlags = 0;
+		unsigned int ulApptStateFlags = 0, ulReminderDelta = 0, ulReminderSet = 0;
+		unsigned int ulBusyStatus = 0, ulAttachment = 0, ulSubType = 0;
+		unsigned int ulAppointmentColor = 0;
 	};
 
-	class _kc_hidden ExtendedException KC_FINAL {
+	class KC_HIDDEN ExtendedException KC_FINAL {
 		public:
-		unsigned int ulChangeHighlightValue;
-		std::string strReserved;
-		std::string strReservedBlock1;
-		unsigned int ulStartDateTime;
-		unsigned int ulEndDateTime;
-		unsigned int ulOriginalStartDate;
-		std::wstring strWideCharSubject;
-		std::wstring strWideCharLocation;
-		std::string strReservedBlock2;
+		unsigned int ulChangeHighlightValue = 0, ulStartDateTime = 0;
+		unsigned int ulEndDateTime = 0, ulOriginalStartDate = 0;
+		std::wstring strWideCharSubject, strWideCharLocation;
+		std::string strReserved, strReservedBlock1, strReservedBlock2;
 	};
 
-	unsigned int ulReaderVersion = 0x3004;
-	unsigned int ulWriterVersion = 0x3004;
+	unsigned int ulReaderVersion = 0x3004, ulWriterVersion = 0x3004;
 	unsigned int ulRecurFrequency = 0; /* "invalid" */
 	unsigned int ulPatternType = PT_DAY;
-	unsigned int ulCalendarType = 0;
-	unsigned int ulFirstDateTime = 0;
-	unsigned int ulPeriod = 0;
+	unsigned int ulCalendarType = 0, ulFirstDateTime = 0, ulPeriod = 0;
 	unsigned int ulSlidingFlag = 0;
 
 	// pattern type specific:
@@ -115,15 +101,11 @@ class _kc_export RecurrenceState KC_FINAL {
 	unsigned int ulDayOfMonth = 0; // monthly, day in month
 	unsigned int ulWeekNumber = 0; // monthly, 1-4 or 5 for last
 
-	unsigned int ulEndType = 0;
-	unsigned int ulOccurrenceCount = 0;
+	unsigned int ulEndType = 0, ulOccurrenceCount = 0;
 	unsigned int ulFirstDOW = DOW_MONDAY; /* default Outlook */
-	unsigned int ulDeletedInstanceCount = 0;
-	std::vector<unsigned int> lstDeletedInstanceDates;
-	unsigned int ulModifiedInstanceCount = 0;
-	std::vector<unsigned int> lstModifiedInstanceDates;
-	unsigned int ulStartDate = 0;
-	unsigned int ulEndDate = 0;
+	unsigned int ulDeletedInstanceCount = 0, ulModifiedInstanceCount = 0;
+	unsigned int ulStartDate = 0, ulEndDate = 0;
+	std::vector<unsigned int> lstDeletedInstanceDates, lstModifiedInstanceDates;
 
 	unsigned int ulReaderVersion2 = 0x3006;
 	unsigned int ulWriterVersion2 = 0x3008; /* can also be 3009, but Outlook (2003) sets 3008 */
@@ -132,11 +114,8 @@ class _kc_export RecurrenceState KC_FINAL {
 
 	unsigned int ulExceptionCount = 0;
 	std::vector<Exception> lstExceptions;
-	std::string strReservedBlock1;
 	std::vector<ExtendedException> lstExtendedExceptions;
-	std::string strReservedBlock2;
+	std::string strReservedBlock1, strReservedBlock2;
 };
 
 } /* namespace */
-
-#endif
