@@ -2,10 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-
-#ifndef convert_INCLUDED
-#define convert_INCLUDED
-
+#pragma once
 #include <kopano/zcdefs.h>
 #include <map>
 #include <set>
@@ -58,7 +55,7 @@ class KC_EXPORT_THROW illegal_sequence_exception KC_FINAL :
 /**
  * @brief	Performs the generic iconv processing.
  */
-class _kc_export iconv_context_base {
+class KC_EXPORT iconv_context_base {
 	public:
 	virtual ~iconv_context_base();
 
@@ -86,7 +83,7 @@ class _kc_export iconv_context_base {
 	 * @param[in] lpBuf		Pointer to the data to be appended.
 	 * @param[in] cbBuf		Size of the data to be appended in bytes.
 	 */
-	_kc_hidden virtual void append(const char *buf, size_t bufsize) = 0;
+	KC_HIDDEN virtual void append(const char *buf, size_t bufsize) = 0;
 
 	iconv_t	m_cd = reinterpret_cast<iconv_t>(-1);
 	bool m_bForce = true; /* Ignore illegal sequences by default. */
@@ -156,7 +153,7 @@ class KC_EXPORT_DYCAST iconv_context KC_FINAL :
 	}
 
 	private:
-	_kc_hidden void append(const char *lpBuf, size_t cbBuf) _kc_override
+	KC_HIDDEN void append(const char *lpBuf, size_t cbBuf) KC_OVERRIDE
 	{
 		m_to.append(reinterpret_cast<typename To_Type::const_pointer>(lpBuf),
 			cbBuf / sizeof(typename To_Type::value_type));
@@ -219,7 +216,7 @@ inline To_Type convert_to(const char *tocode, const From_Type &from,
  * same context. This basically means that the iconv_context classes can
  * be reused, removing the need to recreate them for each conversion.
  */
-class _kc_export convert_context KC_FINAL {
+class KC_EXPORT convert_context KC_FINAL {
 public:
 	convert_context(void) = default;
 	~convert_context();
@@ -234,7 +231,7 @@ public:
 	 * @return					The converted string.
 	 */
 	template<typename To_Type, typename From_Type>
-	_kc_hidden To_Type convert_to(const From_Type &from)
+	KC_HIDDEN To_Type convert_to(const From_Type &from)
 	{
 		return helper<To_Type>(*this).convert(from);
 	}
@@ -251,7 +248,7 @@ public:
 	 * @return					The converted string.
 	 */
 	template<typename To_Type, typename From_Type>
-	_kc_hidden To_Type convert_to(const From_Type &from, size_t cbBytes,
+	KC_HIDDEN To_Type convert_to(const From_Type &from, size_t cbBytes,
 	    const char *fromcode)
 	{
 		return helper<To_Type>(*this).convert(from, cbBytes, fromcode);
@@ -269,10 +266,10 @@ public:
 	 * @return					The converted string.
 	 */
 	template<typename To_Type, typename From_Type>
-	_kc_hidden To_Type convert_to(const char *tocode,
-	    const From_Type &_from, size_t cbBytes, const char *fromcode)
+	KC_HIDDEN To_Type convert_to(const char *tocode,
+	    const From_Type &from, size_t cbBytes, const char *fromcode)
 	{
-		return helper<To_Type>(*this).convert(tocode, _from, cbBytes, fromcode);
+		return helper<To_Type>(*this).convert(tocode, from, cbBytes, fromcode);
 	}
 
 private:
@@ -282,7 +279,7 @@ private:
 	 * The convert_context::helper class detects when the to and from charsets are
 	 * identical. In that case the string is merely copied.
 	 */
-	template<typename Type> class _kc_hidden helper KC_FINAL {
+	template<typename Type> class KC_HIDDEN helper KC_FINAL {
 	public:
 		helper(convert_context &context)
 			: m_context(context)
@@ -351,7 +348,7 @@ private:
 	 * result needs to be stores to guarantee storage of the data. Without this
 	 * the caller will end up with a pointer to non-existing data.
 	 */
-	template<typename Type> class _kc_hidden helper<Type *> KC_FINAL {
+	template<typename Type> class KC_HIDDEN helper<Type *> KC_FINAL {
 	public:
 		typedef std::basic_string<Type> string_type;
 
@@ -456,7 +453,7 @@ private:
 	 * @return	The new context_key
 	 */
 	template<typename To_Type, typename From_Type>
-	_kc_hidden context_key create_key(const char *tocode,
+	KC_HIDDEN context_key create_key(const char *tocode,
 	    const char *fromcode)
 	{
 		context_key key = {
@@ -482,14 +479,14 @@ private:
 	 * @brief Obtains an iconv_context object.
 	 *
 	 * The correct iconv_context is based on To_Type and From_Type and is
-	 * obtained from the context_map. If the correct iconv_context is not found a new
+	 * obtained from the context_map. If the correct iconv_context is not found, a new
 	 * one is created and stored in the context_map;
 	 * @tparam	To_Type	The type of the destination string.
 	 * @tparam	From_Type	The type of the source string.
 	 * @return				A pointer to a iconv_context.
 	 */
 	template<typename To_Type, typename From_Type>
-	_kc_hidden iconv_context<To_Type, From_Type> *get_context(void)
+	KC_HIDDEN iconv_context<To_Type, From_Type> *get_context(void)
 	{
 		context_key key(create_key<To_Type, From_Type>(NULL, NULL));
 		context_map::const_iterator iContext = m_contexts.find(key);
@@ -504,14 +501,14 @@ private:
 	 * @brief Obtains an iconv_context object.
 	 *
 	 * The correct iconv_context is based on To_Type and fromcode and is
-	 * obtained from the context_map. If the correct iconv_context is not found a new
+	 * obtained from the context_map. If the correct iconv_context is not found, a new
 	 * one is created and stored in the context_map;
 	 * @tparam		To_Type	The type of the destination string.
 	 * @param[in]	fromcode	The source charset.
 	 * @return					A pointer to a iconv_context.
 	 */
 	template<typename To_Type, typename From_Type>
-	_kc_hidden iconv_context<To_Type, From_Type> *
+	KC_HIDDEN iconv_context<To_Type, From_Type> *
 	get_context(const char *fromcode)
 	{
 		context_key key(create_key<To_Type, From_Type>(NULL, fromcode));
@@ -531,14 +528,14 @@ private:
 	 * @brief Obtains an iconv_context object.
 	 *
 	 * The correct iconv_context is based on tocode and fromcode and is
-	 * obtained from the context_map. If the correct iconv_context is not found a new
+	 * obtained from the context_map. If the correct iconv_context is not found, a new
 	 * one is created and stored in the context_map;
 	 * @param[in]	tocode		The destination charset.
 	 * @param[in]	fromcode	The source charset.
 	 * @return					A pointer to a iconv_context.
 	 */
 	template<typename To_Type, typename From_Type>
-	_kc_hidden iconv_context<To_Type, From_Type> *
+	KC_HIDDEN iconv_context<To_Type, From_Type> *
 	get_context(const char *tocode, const char *fromcode)
 	{
 		context_key key(create_key<To_Type, From_Type>(tocode, fromcode));
@@ -568,7 +565,7 @@ private:
 	 *
 	 * @param[in,out]	key		The key for which the second field will be persisted.
 	 */
-	_kc_export void persist_code(context_key &key, unsigned flags);
+	void persist_code(context_key &key, unsigned flags);
 
 	/**
 	 * Persist the string so a raw pointer to its content can be used.
@@ -635,7 +632,7 @@ private:
  */
 #define TO_UTF8_DEF(ptr) TO_UTF8(converter, (ptr), ulFlags)
 
-extern _kc_export HRESULT HrFromException(const convert_exception &);
+extern KC_EXPORT HRESULT HrFromException(const convert_exception &);
 
 #ifdef MAPIDEFS_H
 
@@ -729,5 +726,3 @@ HRESULT TryConvert(convert_context &context, const From_Type &from,
 #endif // MAPIDEFS_H
 
 } /* namespace */
-
-#endif // ndef convert_INCLUDED
