@@ -2,10 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-
-#ifndef convstring_INCLUDED
-#define convstring_INCLUDED
-
+#pragma once
 #include <kopano/zcdefs.h>
 #include <kopano/charset/convert.h>
 #include <string>
@@ -14,13 +11,13 @@
 
 namespace KC {
 
-class _kc_export convstring KC_FINAL {
+class KC_EXPORT convstring KC_FINAL {
 public:
 	static convstring from_SPropValue(const SPropValue *lpsPropVal);
-	_kc_hidden static convstring from_SPropValue(const SPropValue &);
-	_kc_hidden convstring(void) = default;
-	_kc_hidden convstring(const convstring &);
-	_kc_hidden convstring(const char *);
+	KC_HIDDEN static convstring from_SPropValue(const SPropValue &);
+	KC_HIDDEN convstring() = default;
+	KC_HIDDEN convstring(const convstring &);
+	KC_HIDDEN convstring(const char *);
 	convstring(const wchar_t *lpsz);
 	convstring(const TCHAR *lpsz, ULONG ulFlags);
 
@@ -33,8 +30,8 @@ public:
 	const char *u8_str() const;
 
 private:
-	template<typename T> _kc_hidden T convert_to(void) const;
-	template<typename T> _kc_hidden T convert_to(const char *tocode) const;
+	template<typename T> KC_HIDDEN T convert_to() const;
+	template<typename T> KC_HIDDEN T convert_to(const char *tocode) const;
 
 	const TCHAR *m_lpsz = nullptr;
 	ULONG m_ulFlags = 0;
@@ -44,5 +41,3 @@ private:
 };
 
 } /* namespace */
-
-#endif // ndef convstring_INCLUDED
