@@ -1,23 +1,8 @@
 /*
+ * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
  */
-
-#ifndef mapi_ptr_INCLUDED
-#define mapi_ptr_INCLUDED
-
+#pragma once
 #include <kopano/memory.hpp>
 #include <mapix.h>
 #include <mapispi.h>
@@ -53,5 +38,3 @@ typedef memory_ptr<SPropValue> SPropArrayPtr;
 typedef rowset_ptr SRowSetPtr;
 
 } /* namespace */
-
-#endif // ndef mapi_ptr_INCLUDED
