@@ -3,9 +3,7 @@
  * Copyright 2005 - 2016 Zarafa and its licensors
  * Copyright 2016 Kopano and its licensors
  */
-#ifndef _KC_MEMORY_HPP
-#define _KC_MEMORY_HPP 1
-
+#pragma once
 #include <kopano/zcdefs.h>
 #include <type_traits> /* std::is_base_of */
 #include <utility> /* std::swap */
@@ -176,8 +174,8 @@ template<typename T, typename Deleter = default_delete> class memory_ptr {
 /* Extra proxy class to forbid AddRef/Release */
 template<typename T> class object_rcguard final : public T {
 	private:
-	virtual unsigned int AddRef() = 0;
-	virtual unsigned int Release() = 0;
+	virtual unsigned int AddRef() { return T::AddRef(); }
+	virtual unsigned int Release() { return T::Release(); }
 };
 
 /**
@@ -189,9 +187,9 @@ template<typename T> class object_ptr {
 	typedef T *pointer;
 	constexpr object_ptr(void) noexcept {}
 	constexpr object_ptr(std::nullptr_t) noexcept {}
-	explicit object_ptr(T *p, bool addref = true) : m_ptr(p)
+	explicit object_ptr(T *p) : m_ptr(p)
 	{
-		if (addref && m_ptr != pointer())
+		if (m_ptr != pointer())
 			m_ptr->AddRef();
 	}
 	~object_ptr(void)
@@ -403,5 +401,3 @@ template<typename T, typename... Args> inline typename mkuniq_helper<T>::invalid
 make_unique_nt(Args &&...) = delete;
 
 } /* namespace */
-
-#endif /* _KC_MEMORY_HPP */
