@@ -2,9 +2,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-#ifndef PLATFORM_LINUX_H
-#define PLATFORM_LINUX_H
-
+#pragma once
 #ifndef UNICODE
 #        error But KC libmapi only knows to deal with UNICODE
 #endif
@@ -32,11 +30,7 @@
 #include <clocale>
 
 #define __STDC_FORMAT_MACROS
-#if defined(__cplusplus) && __cplusplus >= 200300L
-#	include <cstdint>
-#else
-#	include <stdint.h>
-#endif
+#include <cstdint>
 #include <string>
 #ifdef HAVE_UNISTD_H
   #include <unistd.h>
@@ -129,15 +123,14 @@ typedef FMTID* LPFMTID;
 
 typedef GUID  UUID;		// needed? existing?
 
-/* See initguid.h for the real defines */
+#define GUID_EXT extern "C"
+#define KC_DECLARE_GUID(n,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8) GUID_EXT KC_EXPORT const GUID n
+#define KC_DEFINE_GUID(n,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8) \
+	GUID_EXT KC_EXPORT constexpr const GUID n = \
+		{cpu_to_le32(l), cpu_to_le16(w1), cpu_to_le16(w2), \
+		{b1, b2, b3, b4, b5, b6, b7, b8}}
 #ifndef INITGUID
-/* # ifdef __cplusplus */
-/* #   define EXTERN_C extern "C" */
-/* # else */
-/* #   define EXTERN_C extern */
-/* # endif */
-  #define GUID_EXT extern "C"
-  #define DEFINE_GUID(n,l,w1,w2,b1,b2,b3,b4,b5,b6,b7,b8) GUID_EXT _kc_export const GUID n
+#	define DEFINE_GUID KC_DECLARE_GUID
 #endif
 
 #define DEFINE_OLEGUID(n,l,w1,w2) DEFINE_GUID(n,l,w1,w2,0xC0,0,0,0,0,0,0,0x46)
@@ -221,7 +214,7 @@ typedef int				SCODE;
 #define E_ACCESSDENIED ((HRESULT)0x80070005)
 
 /* winerror.h definitions */
-#define KC_HRESULT_TYPEDEF_(_sc) ((HRESULT)_sc)
+#define KC_HRESULT_TYPEDEF_(sc) static_cast<HRESULT>(sc)
 #define STG_E_INVALIDFUNCTION KC_HRESULT_TYPEDEF_(0x80030001L)
 
 /*
@@ -382,24 +375,31 @@ typedef OLECHAR** SNB;
 typedef DWORD LCID;
 
 /* functions */
-extern _kc_export bool operator!=(const GUID &, const GUID &) noexcept;
-extern _kc_export bool operator==(REFIID, const GUID &) noexcept;
+inline bool operator!=(const GUID &a, const GUID &b) noexcept
+{
+	return memcmp(&a, &b, sizeof(GUID)) != 0;
+}
+
+inline bool operator==(const GUID &a, const GUID &b) noexcept
+{
+	return memcmp(&a, &b, sizeof(GUID)) == 0;
+}
 
 extern "C" {
 
-extern _kc_export HRESULT CoCreateGuid(LPGUID);
-extern _kc_export void GetSystemTimeAsFileTime(FILETIME *);
+extern KC_EXPORT HRESULT CoCreateGuid(GUID *);
+extern KC_EXPORT void GetSystemTimeAsFileTime(FILETIME *);
 
 #define _tcslen	wcslen
 #define _tcscpy wcscpy
 #define _tcscmp wcscmp
 #define _tcsicmp wcscasecmp
 
-extern _kc_export void Sleep(unsigned int usec);
+extern KC_EXPORT void Sleep(unsigned int usec);
 
 /* because the flags are not used linux, they do not match the windows flags! */
 #define GPTR 0
-extern _kc_export void * GlobalAlloc(UINT flags, ULONG size);
+extern KC_EXPORT void *GlobalAlloc(unsigned int flags, unsigned int size);
 
 } /* extern "C" */
 
@@ -415,8 +415,8 @@ typedef void * DLIB;
 
 namespace KC {
 
-extern _kc_export void le_to_cpu(SYSTEMTIME &);
-extern _kc_export time_t GetProcessTime(void);
+extern KC_EXPORT void le_to_cpu(SYSTEMTIME &);
+extern KC_EXPORT time_t GetProcessTime();
 
 #define GetTickCount() 0L
 
@@ -434,5 +434,3 @@ extern _kc_export time_t GetProcessTime(void);
 std::vector<std::string> get_backtrace();
 
 } /* namespace */
-
-#endif // PLATFORM_LINUX_H
