@@ -1,6 +1,4 @@
-#ifndef _KC_SCOPE_HPP
-#define _KC_SCOPE_HPP 1
-
+#pragma once
 #include <stdexcept>
 #include <utility>
 
@@ -15,7 +13,16 @@ template<typename F> class scope_success {
 	public:
 	explicit scope_success(F &&f) : m_func(std::move(f)), m_eod(true) {}
 	scope_success(scope_success &&o) : m_func(std::move(o.m_func)), m_eod(o.m_eod) {}
-	~scope_success() noexcept(noexcept(m_func())) { if (m_eod && !std::uncaught_exception()) m_func(); }
+	~scope_success() noexcept(noexcept(m_func()))
+	{
+#if __cplusplus >= 201700L
+		if (m_eod && std::uncaught_exceptions() == 0)
+			m_func();
+#else
+		if (m_eod && !std::uncaught_exception())
+			m_func();
+#endif
+	}
 	void operator=(scope_success &&) = delete;
 };
 
@@ -25,5 +32,3 @@ template<typename F> scope_success<F> make_scope_success(F &&f)
 }
 
 } /* namespace */
-
-#endif /* _KC_SCOPE_HPP */
