@@ -10,9 +10,7 @@
  * @addtogroup libfreebusy
  * @{
  */
-#ifndef ECFREEBUSYUTIL_H
-#define ECFREEBUSYUTIL_H
-
+#pragma once
 #include <string>
 #include "freebusy.h"
 #include "ECFBBlockList.h"
@@ -27,6 +25,4 @@ extern HRESULT HrAddFBBlock(const OccrInfo &sOccrInfo, OccrInfo **lppsOccrInfo,
 
 } /* namespace */
 
-#endif // ECFREEBUSYUTIL_H
-
 /** @} */
