@@ -2,14 +2,12 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-
 /*
  * mapidefs.h – Defines frequently used event types, property types, flags,
  * structures and interfaces.
  */
-#ifndef __M4L_MAPIDEFS_H_
-#define __M4L_MAPIDEFS_H_
-#define MAPIDEFS_H
+#pragma once
+#define MAPIDEFS_H /* used in convert.h */
 
 #include <kopano/platform.h>
 #include <initializer_list>
@@ -55,7 +53,6 @@
 
 #define hrSuccess		0
 
-
 /* Bit definitions for abFlags[0] of ENTRYID */
 #define MAPI_SHORTTERM		0x80
 #define MAPI_NOTRECIP		0x40
@@ -70,8 +67,7 @@
 struct ENTRYID {
 	ENTRYID(void) = delete;
 	template<typename T> ENTRYID(std::initializer_list<T>) = delete;
-    BYTE    abFlags[4];
-    BYTE    ab[MAPI_DIM];
+	BYTE abFlags[4], ab[MAPI_DIM];
 };
 typedef struct ENTRYID *LPENTRYID;
 
@@ -83,8 +79,12 @@ struct ENTRYID_ ## name { \
 } name
 
 /* Byte-order-independent version of GUID (world-unique identifier) */
-struct MAPIUID {
+struct KC_EXPORT MAPIUID {
     BYTE ab[16];
+	inline bool operator==(const MAPIUID &b) const noexcept { return memcmp(ab, b.ab, sizeof(ab)) == 0; }
+	inline bool operator!=(const MAPIUID &b) const noexcept { return memcmp(ab, b.ab, sizeof(ab)) != 0; }
+	inline bool operator==(const GUID &b) const noexcept { static_assert(sizeof(GUID) == sizeof(MAPIUID), ""); return memcmp(ab, &b, sizeof(ab)) == 0; }
+	inline bool operator!=(const GUID &b) const noexcept { return memcmp(ab, &b, sizeof(ab)) != 0; }
 };
 typedef struct MAPIUID *LPMAPIUID;
 
@@ -100,6 +100,19 @@ typedef struct MAPIUID *LPMAPIUID;
 #define MAPI_ONE_OFF_UID { 0x81, 0x2b, 0x1f, 0xa4, 0xbe, 0xa3, 0x10, 0x19, \
                            0x9d, 0x6e, 0x00, 0xdd, 0x01, 0x0f, 0x54, 0x02 } /* MUIDOOP */
 #define MAPI_ONE_OFF_UNICODE        0x8000
+#define MAPI_ONE_OFF_NOLOOKUP       0x1000
+
+#define MAPI_ONE_OFF_MAEMASK        0x0060
+#define MAPI_ONE_OFF_BINHEX         0x0000
+#define MAPI_ONE_OFF_UUENCODE       0x0020
+#define MAPI_ONE_OFF_APPLESINGLE    0x0040
+#define MAPI_ONE_OFF_APPLEDOUBLE    0x0060
+
+#define MAPI_ONE_OFF_FMTMASK        0x001E
+#define MAPI_ONE_OFF_TEXTONLY       0x0006
+#define MAPI_ONE_OFF_HTMLONLY       0x000E
+#define MAPI_ONE_OFF_TEXTANDHTML    0x0016
+
 #define MAPI_ONE_OFF_NO_RICH_INFO   0x0001
 
 /* object types */
@@ -153,14 +166,12 @@ typedef struct MAPIUID *LPMAPIUID;
  *  field of the property value structure which should be
  *  dereferenced to obtain the string pointer.
  */
-
 #define PT_TSTRING          PT_UNICODE
 #define PT_MV_TSTRING       (MV_FLAG|PT_UNICODE)
 #define LPSZ                lpszW
 #define LPPSZ               lppszW
 #define MVSZ                MVszW
 
-
     /* Property Tags */
 #define PROP_TYPE_MASK			((ULONG)0x0000FFFF)
 #define PROP_TYPE(ulPropTag)		(((ULONG)(ulPropTag))&PROP_TYPE_MASK)
@@ -169,9 +180,7 @@ typedef struct MAPIUID *LPMAPIUID;
 #define PROP_ID_NULL            0
 #define PROP_ID_INVALID         0xFFFF
 #define PR_NULL                 PROP_TAG( PT_NULL, PROP_ID_NULL)
-#define CHANGE_PROP_TYPE(ulPropTag, ulPropType) \
-                        (((ULONG)0xFFFF0000 & ulPropTag) | ulPropType)
-
+#define CHANGE_PROP_TYPE(ulPropTag, ulPropType) ((0xFFFF0000U & (ulPropTag)) | (ulPropType))
 
 /* Multi-valued Property Types */
 #define PT_MV_SHORT     (MV_FLAG|PT_SHORT)
@@ -199,15 +208,13 @@ typedef struct MAPIUID *LPMAPIUID;
 #define MVI_FLAG        (MV_FLAG | MV_INSTANCE)
 #define MVI_PROP(tag)   ((tag) | MVI_FLAG)
 
-
 /* Data Structures */
 
 /* Property Tag Array */
 struct SPropTagArray {
 	SPropTagArray(void) = delete;
 	template<typename T> SPropTagArray(std::initializer_list<T>) = delete;
-    ULONG   cValues;
-    ULONG   aulPropTag[MAPI_DIM];
+	unsigned int cValues, aulPropTag[MAPI_DIM];
 };
 typedef struct SPropTagArray *LPSPropTagArray;
 
@@ -224,7 +231,6 @@ struct SPropTagArray_ ## name { \
 	operator const SPropTagArray *(void) const { return reinterpret_cast<const SPropTagArray *>(this); } \
 } name
 
-
 /* Property Value */
 
 /* 32-bit version only, in little endian, Lo is unsigned because the sign bit is in Hi */
@@ -234,8 +240,7 @@ struct SPropTagArray_ ## name { \
 union CURRENCY {
     __extension__ struct {
 #ifdef _USE_NETWORK_ORDER
-        LONG Hi;
-        LONG Lo;
+		int Hi, Lo;
 #else
         ULONG Lo;
         LONG Hi;
@@ -498,7 +503,6 @@ typedef FREEBUFFER* LPFREEBUFFER;
 /* Pointers to MAPI Interfaces */
 typedef const IID* LPCIID;
 
-
 /* Extended MAPI Error Information */
 struct MAPIERROR {
     ULONG   ulVersion;
@@ -508,22 +512,22 @@ struct MAPIERROR {
 typedef MAPIERROR *LPMAPIERROR;
 
 // pre definitions
-class IMsgStore;
-class IMAPIFolder;
-class IMessage;
-class IAttach;
-class IAddrBook;
-class IABContainer;
-class IMailUser;
-class IDistList;
-class IMAPIStatus;
-class IMAPITable;
-class IProfSect;
-class IMAPIProp;
-class IMAPIContainer;
-class IMAPIAdviseSink;
-class IMAPIProgress;
-class IProviderAdmin;
+struct IMsgStore;
+struct IMAPIFolder;
+struct IMessage;
+struct IAttach;
+struct IAddrBook;
+struct IABContainer;
+struct IMailUser;
+struct IDistList;
+struct IMAPIStatus;
+struct IMAPITable;
+struct IProfSect;
+struct IMAPIProp;
+struct IMAPIContainer;
+struct IMAPIAdviseSink;
+struct IMAPIProgress;
+struct IProviderAdmin;
 
 typedef IMsgStore* LPMDB;
 typedef IMAPIFolder* LPMAPIFOLDER;
@@ -579,7 +583,7 @@ struct MAPINAMEID {
 typedef struct MAPINAMEID *LPMAPINAMEID;
 
 /* IUnknown Interface */
-class IUnknown {
+struct IUnknown {
 public:
 	virtual ~IUnknown() = default;
 	virtual ULONG AddRef() = 0;
@@ -590,14 +594,14 @@ IID_OF(IUnknown)
 typedef IUnknown *LPUNKNOWN;
 
 /* IStream Interface */
-class ISequentialStream : public virtual IUnknown {
+struct ISequentialStream : public virtual IUnknown {
 	public:
 	virtual HRESULT Read(void *pv, ULONG cb, ULONG *pcbRead) = 0;
 	virtual HRESULT Write(const void *pv, ULONG cb, ULONG *pcbWritten) = 0;
 };
 IID_OF(ISequentialStream)
 
-class IEnumSTATSTG : public virtual IUnknown {
+struct IEnumSTATSTG : public virtual IUnknown {
 	public:
 	virtual HRESULT Next(ULONG celt, STATSTG *rgelt, ULONG *pceltFetched) = 0;
 	virtual HRESULT Skip(ULONG celt) = 0;
@@ -609,7 +613,7 @@ DEFINE_OLEGUID(IID_IEnumSTATSTG, 0x0D, 0, 0);
 #endif
 IID_OF(IEnumSTATSTG)
 
-class IStream : public virtual ISequentialStream {
+struct IStream : public virtual ISequentialStream {
 	public:
 	virtual HRESULT Seek(LARGE_INTEGER dlibMove, DWORD dwOrigin, ULARGE_INTEGER *plibNewPosition) = 0;
 	virtual HRESULT SetSize(ULARGE_INTEGER libNewSize) = 0;
@@ -624,7 +628,7 @@ class IStream : public virtual ISequentialStream {
 IID_OF(IStream)
 typedef IStream *LPSTREAM;
 
-class IMalloc : public virtual IUnknown {
+struct IMalloc : public virtual IUnknown {
 	public:
 	virtual void *Alloc(ULONG cb) = 0;
 	virtual void *Realloc(void *pv, ULONG cb) = 0;
@@ -635,7 +639,7 @@ class IMalloc : public virtual IUnknown {
 };
 typedef IMalloc *LPMALLOC;
 
-class IStorage : public virtual IUnknown {
+struct IStorage : public virtual IUnknown {
 	public:
 	virtual HRESULT CreateStream(const OLECHAR *pwcsName, DWORD grfMode, DWORD reserved1, DWORD reserved2, IStream **ppstm) = 0;
 	virtual HRESULT OpenStream(const OLECHAR *pwcsName, void *reserved1, DWORD grfMode, DWORD reserved2, IStream **ppstm) = 0;
@@ -656,7 +660,7 @@ class IStorage : public virtual IUnknown {
 IID_OF(IStorage)
 typedef IStorage *LPSTORAGE;
 
-class IMAPIProp : public virtual IUnknown {
+struct IMAPIProp : public virtual IUnknown {
 public:
     virtual HRESULT GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR* lppMAPIError) = 0;
     virtual HRESULT SaveChanges(ULONG ulFlags) = 0;
@@ -688,7 +692,7 @@ IID_OF(IMAPIProp)
 #define FOREGROUND_SEARCH       ((ULONG) 0x00000010)
 #define BACKGROUND_SEARCH       ((ULONG) 0x00000020)
 
-class IMAPIContainer : public virtual IMAPIProp {
+struct IMAPIContainer : public virtual IMAPIProp {
 public:
     virtual HRESULT GetContentsTable(ULONG ulFlags, LPMAPITABLE* lppTable) = 0;
     virtual HRESULT GetHierarchyTable(ULONG ulFlags, LPMAPITABLE* lppTable) = 0;
@@ -781,8 +785,7 @@ struct OBJECT_NOTIFICATION {
 struct TABLE_NOTIFICATION {
     ULONG               ulTableEvent;
     HRESULT             hResult;
-    SPropValue          propIndex;
-    SPropValue          propPrior;
+	SPropValue propIndex, propPrior;
     SRow                row;
     ULONG               ulPad;
 };
@@ -812,7 +815,6 @@ struct NOTIFICATION {
 };
 typedef struct NOTIFICATION *LPNOTIFICATION;
 
-
 /* Callback function type for MAPIAllocAdviseSink */
 typedef LONG (NOTIFCALLBACK)(
     LPVOID          lpvContext,
@@ -821,9 +823,8 @@ typedef LONG (NOTIFCALLBACK)(
 );
 typedef NOTIFCALLBACK *LPNOTIFCALLBACK;
 
-
 /* Interface used for registering and issuing notification callbacks. */
-class IMAPIAdviseSink : public virtual IUnknown {
+struct IMAPIAdviseSink : public virtual IUnknown {
 public:
     virtual ULONG OnNotify(ULONG cNotif, LPNOTIFICATION lpNotifications) = 0;
 };
@@ -870,7 +871,7 @@ IID_OF(IMAPIAdviseSink)
 #define FOLDER_COMMON_VIEWS_VALID       ((ULONG) 0x00000040)
 #define FOLDER_FINDER_VALID             ((ULONG) 0x00000080)
 
-class IMsgStore : public virtual IMAPIProp {
+struct IMsgStore : public virtual IMAPIProp {
 public:
 	virtual HRESULT Advise(ULONG eid_size, const ENTRYID *, ULONG evt_mask, IMAPIAdviseSink *, ULONG *conn) = 0;
     virtual HRESULT Unadvise(ULONG ulConnection) = 0;
@@ -893,7 +894,6 @@ IID_OF(IMsgStore)
  */
 
 /* Data structures (Shared with IMAPITable) */
-
 struct SSortOrder {
     ULONG   ulPropTag;          /* Column to sort on */
     ULONG   ulOrder;            /* Ascending, descending, combine to left */
@@ -947,7 +947,7 @@ struct SSortOrderSet_ ## name { \
 #define FLDSTATUS_HIDDEN        ((ULONG) 0x00000004)
 #define FLDSTATUS_DELMARKED     ((ULONG) 0x00000008)
 
-class IMAPIFolder : public virtual IMAPIContainer {
+struct IMAPIFolder : public virtual IMAPIContainer {
 public:
     virtual HRESULT CreateMessage(LPCIID lpInterface, ULONG ulFlags, LPMESSAGE* lppMessage) = 0;
     virtual HRESULT CopyMessages(LPENTRYLIST lpMsgList, LPCIID lpInterface, LPVOID lpDestFolder, ULONG ulUIParam,
@@ -1002,7 +1002,7 @@ IID_OF(IMAPIFolder)
 #define IMPORTANCE_NORMAL       ((long) 1)
 #define IMPORTANCE_HIGH         ((long) 2)
 
-class IMessage : public virtual IMAPIProp {
+struct IMessage : public virtual IMAPIProp {
 public:
     virtual HRESULT GetAttachmentTable(ULONG ulFlags, LPMAPITABLE *lppTable) = 0;
     virtual HRESULT OpenAttach(ULONG ulAttachmentNum, LPCIID lpInterface, ULONG ulFlags, LPATTACH *lppAttach) = 0;
@@ -1026,7 +1026,7 @@ IID_OF(IMessage)
 #define ATTACH_EMBEDDED_MSG     ((ULONG) 0x00000005)
 #define ATTACH_OLE              ((ULONG) 0x00000006)
 
-class IAttach : public virtual IMAPIProp {
+struct IAttach : public virtual IMAPIProp {
 public:
 };
 IID_OF2(IAttach, IAttachment)
@@ -1046,8 +1046,7 @@ IID_OF2(IAttach, IAttachment)
 struct FlagList {
 	FlagList(void) = delete;
 	template<typename T> FlagList(std::initializer_list<T>) = delete;
-    ULONG cFlags;
-    ULONG ulFlag[MAPI_DIM];
+	unsigned int cFlags, ulFlag[MAPI_DIM];
 };
 typedef struct FlagList *LPFlagList;
 
@@ -1081,7 +1080,7 @@ class IABContainer_DistList_base : public virtual IMAPIContainer {
 
 } /* namespace KC */
 
-class IABContainer : public virtual KC::IABContainer_DistList_base {
+struct IABContainer : public virtual KC::IABContainer_DistList_base {
 };
 IID_OF(IABContainer)
 
@@ -1155,7 +1154,7 @@ IID_OF(IABContainer)
 #define MAPI_MH_DP_PDS_PATRON                       ((ULONG) 5)
 #define MAPI_MH_DP_OTHER_AU                         ((ULONG) 6)
 
-class IMailUser : public virtual IMAPIProp {
+struct IMailUser : public virtual IMAPIProp {
 public:
 };
 IID_OF(IMailUser)
@@ -1163,11 +1162,11 @@ IID_OF(IMailUser)
 /*
  * IDistList Interface
  */
-class IDistList : public virtual KC::IABContainer_DistList_base {
+struct IDistList : public virtual KC::IABContainer_DistList_base {
 };
 IID_OF(IDistList)
 
-class IMAPIStatus : public IMAPIProp {
+struct IMAPIStatus : public IMAPIProp {
 public:
 	virtual HRESULT ValidateState(ULONG ulUIParam, ULONG ulFlags) = 0;
     virtual HRESULT SettingsDialog(ULONG ulUIParam, ULONG ulFlags) = 0;
@@ -1181,7 +1180,6 @@ IID_OF(IMAPIStatus)
  */
 
 /* Table status */
-
 #define TBLSTAT_COMPLETE            ((ULONG) 0)
 #define TBLSTAT_QCHANGED            ((ULONG) 7)
 #define TBLSTAT_SORTING             ((ULONG) 9)
@@ -1191,23 +1189,17 @@ IID_OF(IMAPIStatus)
 #define TBLSTAT_RESTRICTING         ((ULONG) 14)
 #define TBLSTAT_RESTRICT_ERROR      ((ULONG) 15)
 
-
 /* Table Type */
-
 #define TBLTYPE_SNAPSHOT            ((ULONG) 0)
 #define TBLTYPE_KEYSET              ((ULONG) 1)
 #define TBLTYPE_DYNAMIC             ((ULONG) 2)
 
-
 /* Sort order */
-
 /* bit 0: set if descending, clear if ascending */
-
 #define TABLE_SORT_ASCEND       ((ULONG) 0x00000000)
 #define TABLE_SORT_DESCEND      ((ULONG) 0x00000001)
 #define TABLE_SORT_COMBINE      ((ULONG) 0x00000002)
 
-
 typedef ULONG       BOOKMARK;
 
 #define BOOKMARK_BEGINNING  ((BOOKMARK) 0)      /* Before first row */
@@ -1215,7 +1207,6 @@ typedef ULONG       BOOKMARK;
 #define BOOKMARK_END        ((BOOKMARK) 2)      /* After last row */
 
 /* Fuzzy Level */
-
 #define FL_FULLSTRING       ((ULONG) 0x00000000)
 #define FL_SUBSTRING        ((ULONG) 0x00000001)
 #define FL_PREFIX           ((ULONG) 0x00000002)
@@ -1225,9 +1216,7 @@ typedef ULONG       BOOKMARK;
 #define FL_LOOSE            ((ULONG) 0x00040000)
 
 /* Restrictions */
-
 /* Restriction types */
-
 #define RES_AND             ((ULONG) 0x00000000)
 #define RES_OR              ((ULONG) 0x00000001)
 #define RES_NOT             ((ULONG) 0x00000002)
@@ -1241,7 +1230,6 @@ typedef ULONG       BOOKMARK;
 #define RES_COMMENT         ((ULONG) 0x0000000A)
 
 /* Relational operators. These apply to all property comparison restrictions. */
-
 #define RELOP_LT        ((ULONG) 0)     /* <  */
 #define RELOP_LE        ((ULONG) 1)     /* <= */
 #define RELOP_GT        ((ULONG) 2)     /* >  */
@@ -1251,12 +1239,10 @@ typedef ULONG       BOOKMARK;
 #define RELOP_RE        ((ULONG) 6)     /* LIKE (Regular expression) */
 
 /* Bitmask operators, for RES_BITMASK only. */
-
 #define BMR_EQZ     ((ULONG) 0)     /* ==0 */
 #define BMR_NEZ     ((ULONG) 1)     /* !=0 */
 
 /* Subobject identifiers for RES_SUBRESTRICTION only. See MAPITAGS.H. */
-
 /* #define PR_MESSAGE_RECIPIENTS  PROP_TAG(PT_OBJECT,0x0E12) */
 /* #define PR_MESSAGE_ATTACHMENTS PROP_TAG(PT_OBJECT,0x0E13) */
 
@@ -1335,33 +1321,28 @@ struct SRestriction {
 /* Flags of the methods of IMAPITable */
 
 /* QueryColumn */
-
 #define TBL_ALL_COLUMNS     ((ULONG) 0x00000001)
 
 /* QueryRows */
 /* Possible values for PR_ROW_TYPE (for categorization) */
-
 #define TBL_LEAF_ROW            ((ULONG) 1)
 #define TBL_EMPTY_CATEGORY      ((ULONG) 2)
 #define TBL_EXPANDED_CATEGORY   ((ULONG) 3)
 #define TBL_COLLAPSED_CATEGORY  ((ULONG) 4)
 
 /* Table wait flag */
-
 #define TBL_NOWAIT          ((ULONG) 0x00000001)
 /* alternative name for TBL_NOWAIT */
 #define TBL_ASYNC           ((ULONG) 0x00000001)
 #define TBL_BATCH           ((ULONG) 0x00000002)
 
 /* FindRow */
-
 #define DIR_BACKWARD        ((ULONG) 0x00000001)
 
 /* Table cursor states */
-
 #define TBL_NOADVANCE       ((ULONG) 0x00000001)
 
-class IMAPITable : public virtual IUnknown {
+struct IMAPITable : public virtual IUnknown {
 public:
     virtual HRESULT GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR *lppMAPIError) = 0;
     virtual HRESULT Advise(ULONG ulEventMask, LPMAPIADVISESINK lpAdviseSink, ULONG * lpulConnection) = 0;
@@ -1396,7 +1377,6 @@ IID_OF(IMAPITable)
  */
 
 /* Standard section for public profile properties */
-
 #define PS_PROFILE_PROPERTIES_INIT \
 {   0x98, 0x15, 0xAC, 0x08, 0xAA, 0xB0, 0x10, 0x1A, \
     0x8C, 0x93, 0x08, 0x00, 0x2B, 0x2A, 0x56, 0xC2  }
@@ -1462,7 +1442,7 @@ IID_OF(IMAPITable)
 #define FLUSH_NO_UI         ((ULONG) 0x00000010)
 #define FLUSH_ASYNC_OK      ((ULONG) 0x00000020)
 
-class IProfSect : public virtual IMAPIProp {
+struct IProfSect : public virtual IMAPIProp {
 public:
 };
 IID_OF(IProfSect)
@@ -1472,7 +1452,7 @@ IID_OF(IProfSect)
  */
 #define MAPI_TOP_LEVEL      ((ULONG) 0x00000001)
 
-class IMAPIProgress : public virtual IUnknown {
+struct IMAPIProgress : public virtual IUnknown {
 public:
     virtual HRESULT Progress(ULONG ulValue, ULONG ulCount, ULONG ulTotal) = 0;
     virtual HRESULT GetFlags(ULONG* lpulFlags) = 0;
@@ -1490,7 +1470,7 @@ IID_OF(IMAPIProgress)
 #define SERVICE_UI_ALLOWED          0x00000010
 #define UI_CURRENT_PROVIDER_FIRST   0x00000004
 
-class IProviderAdmin : public virtual IUnknown {
+struct IProviderAdmin : public virtual IUnknown {
 public:
     virtual HRESULT GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR* lppMAPIError) = 0;
     virtual HRESULT GetProviderTable(ULONG ulFlags, LPMAPITABLE* lppTable) = 0;
@@ -1549,7 +1529,6 @@ IID_OF(IProviderAdmin)
 #define DTE_REMOTE(v)		(((v) & DTE_MASK_REMOTE) >> 8)
 #define DTE_LOCAL(v)		((v) & DTE_MASK_LOCAL)
 
-
 extern "C" {
 
 /*  Accelerator callback for DIALOG_SDI form of AB UI */
@@ -1589,8 +1568,7 @@ struct ADRPARM {
     LPFNDISMISS     lpfnDismiss;
     LPVOID          lpvDismissContext;
 	TCHAR *lpszCaption, *lpszNewEntryTitle, *lpszDestWellsTitle;
-    ULONG           cDestFields;
-    ULONG           nDestFieldFocus;
+	unsigned int cDestFields, nDestFieldFocus;
     LPTSTR *    lppszDestTitles;
     ULONG *     lpulDestComps;
 	SRestriction *lpContRestriction, *lpHierRestriction;
@@ -1616,15 +1594,12 @@ typedef struct ADRPARM *LPADRPARM;
 /* Flags for OpenAddressBook */
 #define AB_NO_DIALOG            ((ULONG) 0x00000001)
 
-/*-----------*/
-
-
 /*
  * IMAPIControl Interface
  */
 #define  MAPI_ENABLED       ((ULONG) 0x00000000)
 #define  MAPI_DISABLED      ((ULONG) 0x00000001)
-class IMAPIControl : public virtual IUnknown {
+struct IMAPIControl : public virtual IUnknown {
 public:
     virtual HRESULT GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR* lppMAPIError) = 0;
     virtual HRESULT Activate(ULONG ulFlags, ULONG ulUIParam) = 0;
@@ -1699,7 +1674,6 @@ struct DTBLCOMBOBOX_ ## u { \
     TCHAR           lpszCharsAllowed[n]; \
 } u
 
-
 /*  Drop Down   */
 struct DTBLDDLBX {
 	ULONG ulFlags, ulPRDisplayProperty, ulPRSetProperty, ulPRTableName;
@@ -1717,7 +1691,6 @@ struct DTBLCHECKBOX_ ## u { \
     TCHAR       lpszLabel[n]; \
 } u
 
-
 /*  Group Box   */
 struct DTBLGROUPBOX {
 	ULONG ulbLpszLabel, ulFlags;
@@ -1729,7 +1702,6 @@ struct DTBLGROUPBOX_ ## u { \
     TCHAR           lpszLabel[n]; \
 } u
 
-
 /*  Button control   */
 struct DTBLBUTTON {
 	ULONG ulbLpszLabel, ulFlags, ulPRControl;
@@ -1741,7 +1713,6 @@ struct DTBLBUTTON_ ## u { \
     TCHAR       lpszLabel[n]; \
 } u
 
-
 /*  Pages   */
 struct DTBLPAGE {
 	ULONG ulbLpszLabel, ulFlags, ulbLpszComponent, ulContext;
@@ -1750,11 +1721,9 @@ typedef struct DTBLPAGE *LPDTBLPAGE;
 #define SizedDtblPage(n,n1,u) \
 struct DTBLPAGE_ ## u { \
     DTBLPAGE    dtblpage; \
-    TCHAR       lpszLabel[n]; \
-    TCHAR       lpszComponent[n1]; \
+	TCHAR lpszLabel[n], lpszComponent[n1]; \
 } u
 
-
 /*  Radio button   */
 struct DTBLRADIOBUTTON {
 	ULONG ulbLpszLabel, ulFlags, ulcButtons, ulPropTag;
@@ -1767,7 +1736,6 @@ struct DTBLRADIOBUTTON_ ## u { \
     TCHAR           lpszLabel[n]; \
 } u
 
-
 /*  MultiValued listbox */
 struct DTBLMVLISTBOX {
 	ULONG ulFlags, ulMVPropTag;
@@ -1779,5 +1747,3 @@ struct DTBLMVDDLBX {
 	ULONG ulFlags, ulMVPropTag;
 };
 typedef struct DTBLMVDDLBX *LPDTBLMVDDLBX;
-
-#endif /* MAPIDEFS_H */
