@@ -1,28 +1,12 @@
 /*
+ * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 /*
  * mapispi.h – Defines flags and interfaces that MAPI implements for service
  * providers and message services.
  */
-
-#ifndef __M4L_MAPISPI_H_
-#define __M4L_MAPISPI_H_
-#define MAPISPI_H
-
+#pragma once
 #include <kopano/platform.h>
 #include <initializer_list>
 #include <mapidefs.h>
@@ -30,7 +14,6 @@
 #include <mapiguid.h>
 #include <mapitags.h>
 
-
 /*  The MAPI SPI has a version number.  MAPIX.DLL knows and supports
  *  one or more versions of the SPI.  Each provider supports one or
  *  more versions of the SPI.  Checks are performed in both MAPIX.DLL
@@ -74,7 +57,6 @@ typedef IMAPISupport* LPMAPISUP;
  */
 
 /* Notification key structure for the MAPI notification engine */
-
 struct NOTIFKEY {
 	NOTIFKEY(void) = delete;
 	template<typename T> NOTIFKEY(std::initializer_list<T>) = delete;
@@ -83,30 +65,24 @@ struct NOTIFKEY {
 };
 typedef struct NOTIFKEY *LPNOTIFKEY;
 
-#define CbNewNOTIFKEY(_cb)      (offsetof(NOTIFKEY,ab) + (_cb))
-#define CbNOTIFKEY(_lpkey)      (offsetof(NOTIFKEY,ab) + (_lpkey)->cb)
-#define SizedNOTIFKEY(_cb, _name) \
-struct _NOTIFKEY_ ## _name { \
+#define CbNewNOTIFKEY(cb) (offsetof(NOTIFKEY, ab) + (cb))
+#define CbNOTIFKEY(lpkey) (offsetof(NOTIFKEY, ab) + (lpkey)->cb)
+#define SizedNOTIFKEY(cb, name) \
+struct _NOTIFKEY_ ## name { \
     ULONG       cb; \
-    BYTE        ab[_cb]; \
-} _name
-
+	BYTE ab[cb]; \
+} name
 
 /* For Subscribe() */
-
 #define NOTIFY_SYNC             ((ULONG) 0x40000000)
 
 /* For Notify() */
-
 #define NOTIFY_CANCELED         ((ULONG) 0x80000000)
 
-
 /* From the Notification Callback function (well, this is really a ulResult) */
-
 #define CALLBACK_DISCONTINUE    ((ULONG) 0x80000000)
 
 /* For Transport's SpoolerNotify() */
-
 #define NOTIFY_NEWMAIL          ((ULONG) 0x00000001)
 #define NOTIFY_READYTOSEND      ((ULONG) 0x00000002)
 #define NOTIFY_SENTDEFERRED     ((ULONG) 0x00000004)
@@ -116,15 +92,12 @@ struct _NOTIFKEY_ ## _name { \
 #define NOTIFY_CRITICAL_ERROR   ((ULONG) 0x10000000)
 
 /* For Message Store's SpoolerNotify() */
-
 #define NOTIFY_NEWMAIL_RECEIVED ((ULONG) 0x20000000)
 
 /* For ModifyStatusRow() */
-
 #define STATUSROW_UPDATE        ((ULONG) 0x10000000)
 
 /* For IStorageFromStream() */
-
 #define STGSTRM_RESET           ((ULONG) 0x00000000)
 #define STGSTRM_CURRENT         ((ULONG) 0x10000000)
 #define STGSTRM_MODIFY          ((ULONG) 0x00000002)
@@ -136,7 +109,6 @@ struct _NOTIFKEY_ ## _name { \
 /* Preprocessor calls: */
 
 /* PreprocessMessage, first ordinal in RegisterPreprocessor(). */
-
 typedef HRESULT (PREPROCESSMESSAGE)(
                     LPVOID lpvSession,
                     LPMESSAGE lpMessage,
@@ -150,7 +122,6 @@ typedef HRESULT (PREPROCESSMESSAGE)(
                     LPADRLIST* lppRecipList);
 
 /* RemovePreprocessInfo, second ordinal in RegisterPreprocessor(). */
-
 typedef HRESULT (REMOVEPREPROCESSINFO)(LPMESSAGE lpMessage);
 
 /* Function pointer for GetReleaseInfo */
@@ -259,10 +230,9 @@ typedef HRESULT (ABPROVIDERINIT)(
     LPABPROVIDER *  lppABProvider
 );
 
-ABPROVIDERINIT ABProviderInit;
+KC_EXPORT ABPROVIDERINIT ABProviderInit;
 }
 
-
 /********************************************************************/
 /*                                                                  */
 /*                          TRANSPORT SPI                           */
@@ -270,14 +240,11 @@ ABPROVIDERINIT ABProviderInit;
 /********************************************************************/
 
 /* For DeinitTransport */
-
 #define DEINIT_NORMAL               ((ULONG) 0x00000001)
 #define DEINIT_HURRY                ((ULONG) 0x80000000)
 
 /* For TransportLogon */
-
 /* Flags that the Spooler may pass to the transport: */
-
 #define LOGON_NO_DIALOG             ((ULONG) 0x00000001)
 #define LOGON_NO_CONNECT            ((ULONG) 0x00000004)
 #define LOGON_NO_INBOUND            ((ULONG) 0x00000008)
@@ -285,12 +252,10 @@ ABPROVIDERINIT ABProviderInit;
 /*#define MAPI_UNICODE              ((ULONG) 0x80000000) in mapidefs.h */
 
 /* Flags that the transport may pass to the Spooler: */
-
 #define LOGON_SP_IDLE               ((ULONG) 0x00010000)
 #define LOGON_SP_POLL               ((ULONG) 0x00020000)
 #define LOGON_SP_RESOLVE            ((ULONG) 0x00040000)
 
-
 class IXPProvider;
 typedef IXPProvider* LPXPPROVIDER;
 
@@ -304,7 +269,6 @@ public:
 };
 
 /* OptionData returned from call to RegisterOptions */
-
 #define OPTION_TYPE_RECIPIENT       ((ULONG) 0x00000001)
 #define OPTION_TYPE_MESSAGE         ((ULONG) 0x00000002)
 
@@ -333,7 +297,6 @@ typedef SCODE (OPTIONCALLBACK)(
             LPMAPIERROR *   lppMAPIError);
 
 /* For TransportNotify */
-
 #define NOTIFY_ABORT_DEFERRED       ((ULONG) 0x40000000)
 #define NOTIFY_CANCEL_MESSAGE       ((ULONG) 0x80000000)
 #define NOTIFY_BEGIN_INBOUND        ((ULONG) 0x00000001)
@@ -346,20 +309,16 @@ typedef SCODE (OPTIONCALLBACK)(
 #define NOTIFY_END_OUTBOUND_FLUSH   ((ULONG) 0x00080000)
 
 /* For TransportLogoff */
-
 #define LOGOFF_NORMAL               ((ULONG) 0x00000001)
 #define LOGOFF_HURRY                ((ULONG) 0x80000000)
 
 /* For SubmitMessage */
-
 #define BEGIN_DEFERRED              ((ULONG) 0x00000001)
 
 /* For EndMessage */
-
 /* Flags that the Spooler may pass to the Transport: */
 
 /* Flags that the transport may pass to the Spooler: */
-
 #define END_RESEND_NOW              ((ULONG) 0x00010000)
 #define END_RESEND_LATER            ((ULONG) 0x00020000)
 #define END_DONT_RESEND             ((ULONG) 0x00040000)
@@ -381,7 +340,6 @@ public:
     virtual HRESULT FlushQueues(ULONG ulUIParam, ULONG cbTargetTransport, LPENTRYID lpTargetTransport, ULONG ulFlags) = 0;
 };
 
-
 /* Transport Provider Entry Point */
 typedef HRESULT (XPPROVIDERINIT)(
     HINSTANCE           hInstance,
@@ -401,16 +359,13 @@ typedef HRESULT (XPPROVIDERINIT)(
 /********************************************************************/
 
 /* Flags and enums */
-
 /* GetCredentials, SetCredentials */
-
 #define LOGON_SP_TRANSPORT      ((ULONG) 0x00000001)
 #define LOGON_SP_PROMPT         ((ULONG) 0x00000002)
 #define LOGON_SP_NEWPW          ((ULONG) 0x00000004)
 #define LOGON_CHANGED           ((ULONG) 0x00000008)
 
 /* DoMCDialog */
-
 #define DIALOG_FOLDER           ((ULONG) 0x00000001)
 #define DIALOG_MESSAGE          ((ULONG) 0x00000002)
 #define DIALOG_PROP             ((ULONG) 0x00000004)
@@ -424,12 +379,10 @@ typedef HRESULT (XPPROVIDERINIT)(
 #define DIALOG_CONFIRM_CANCEL   ((ULONG) 0x00000100)
 
 /* ExpandRecips */
-
 #define NEEDS_PREPROCESSING     ((ULONG) 0x00000001)
 #define NEEDS_SPOOLER           ((ULONG) 0x00000002)
 
 /* PrepareSubmit */
-
 #define CHECK_SENDER            ((ULONG) 0x00000001)
 #define NON_STANDARD            ((ULONG) 0x00010000)
 
@@ -443,10 +396,9 @@ typedef IMSProvider* LPMSPROVIDER;
 class IMSProvider : public virtual IUnknown {
 public: 
     virtual HRESULT Shutdown(ULONG * lpulFlags) = 0; 
-	virtual HRESULT Logon(LPMAPISUP lpMAPISup, ULONG_PTR ulUIParam, const TCHAR *lpszProfileName, ULONG cbEntryID, LPENTRYID lpEntryID, ULONG ulFlags, LPCIID lpInterface, ULONG *lpcbSpoolSecurity, LPBYTE *lppbSpoolSecurity, LPMAPIERROR *lppMAPIError, LPMSLOGON *lppMSLogon, LPMDB *lppMDB) = 0;
-	virtual HRESULT SpoolerLogon(LPMAPISUP lpMAPISup, ULONG_PTR ulUIParam, const TCHAR *lpszProfileName, ULONG cbEntryID, LPENTRYID lpEntryID, ULONG ulFlags, LPCIID lpInterface, ULONG cbSpoolSecurity, LPBYTE lpbSpoolSecurity, LPMAPIERROR *lppMAPIError, LPMSLOGON *lppMSLogon, LPMDB *lppMDB) = 0;
-    virtual HRESULT CompareStoreIDs(ULONG cbEntryID1, LPENTRYID lpEntryID1, ULONG cbEntryID2, LPENTRYID lpEntryID2,
-				    ULONG ulFlags, ULONG * lpulResult) = 0;
+	virtual HRESULT Logon(IMAPISupport *, ULONG_PTR ui_param, const TCHAR *profile, ULONG eid_size, const ENTRYID *eid, ULONG flags, const IID *intf, ULONG *ssec_size, BYTE **spool_sec, MAPIERROR **, IMSLogon **, IMsgStore **) = 0;
+	virtual HRESULT SpoolerLogon(IMAPISupport *, ULONG_PTR ui_param, const TCHAR *profile, ULONG eid_size, const ENTRYID *eid, ULONG flags, const IID *intf, ULONG ssec_size, const BYTE *spool_sec, MAPIERROR **, IMSLogon **, IMsgStore **) = 0;
+	virtual HRESULT CompareStoreIDs(ULONG eid1_size, const ENTRYID *eid1, ULONG eid2_size, const ENTRYID *eid2, ULONG flags, ULONG *result) = 0;
 };
 
 /* The MSLOGON object is returned by the Logon() method of the
@@ -478,7 +430,7 @@ typedef HRESULT (MSPROVIDERINIT)(
     LPMSPROVIDER *      lppMSProvider
 );
 
-MSPROVIDERINIT MSProviderInit;
+KC_EXPORT MSPROVIDERINIT MSProviderInit;
 }
 
 /********************************************************************/
@@ -488,12 +440,10 @@ MSPROVIDERINIT MSProviderInit;
 /********************************************************************/
 
 /* Flags for service configuration entry point */
-
 #define MSG_SERVICE_UI_READ_ONLY     0x00000008 /* display parameters only */
 #define SERVICE_LOGON_FAILED         0x00000020 /* reconfigure provider */
 
 /* Contexts for service configuration entry point */
-
 #define MSG_SERVICE_INSTALL         0x00000001
 #define MSG_SERVICE_CREATE          0x00000002
 #define MSG_SERVICE_CONFIGURE       0x00000003
@@ -519,5 +469,3 @@ typedef HRESULT (MSGSERVICEENTRY)(
 
 typedef MSGSERVICEENTRY *LPMSGSERVICEENTRY;
 }
-
-#endif /* MAPISPI_H */
