@@ -7,35 +7,40 @@ Copyright 2016 - 2019 Kopano and its licensors (see LICENSE file)
 """
 import sys
 
+from datetime import datetime
+
 from MAPI import (
-    PT_SYSTIME, MNID_ID, PT_BOOLEAN, MODRECIP_ADD,
-    PT_LONG, PT_UNICODE,
+    PT_SYSTIME, MODRECIP_ADD, PT_LONG, PT_UNICODE, BMR_EQZ
 )
 
 from MAPI.Tags import (
     PR_MESSAGE_RECIPIENTS, PR_RESPONSE_REQUESTED, PR_ENTRYID,
     PR_DISPLAY_NAME_W, PR_ADDRTYPE_W, PR_EMAIL_ADDRESS_W, PR_RECIPIENT_TYPE,
-    respOrganized,
+    PR_RECIPIENT_FLAGS, respOrganized, recipOrganizer
 )
 
-from MAPI.Struct import SPropValue
+from MAPI.Struct import (SPropValue, SOrRestriction, SBitMaskRestriction,
+                         SExistRestriction, SNotRestriction)
 
 from .attendee import Attendee
 from .errors import NotFoundError, ArgumentError
 from .recurrence import Recurrence, Occurrence
+from .restriction import Restriction
 
 from .compat import (
-    benc as _benc, bdec as _bdec, fake_unicode as _unicode,
+    benc as _benc, bdec as _bdec,
 )
 from .defs import (
-    PSETID_Appointment, ASF_CANCELED, NR_COLOR, COLOR_NR, FB_STATUS,
-    STATUS_FB, ASF_MEETING, RESPONSE_STATUS,
+    ASF_CANCELED, NR_COLOR, COLOR_NR, FB_STATUS,
+    STATUS_FB, ASF_MEETING, RESPONSE_STATUS, STATUS_RESPONSE,
 )
 from .pidlid import (
     PidLidReminderSet, PidLidReminderDelta, PidLidAppointmentSubType,
     PidLidBusyStatus, PidLidGlobalObjectId, PidLidRecurring,
     PidLidTimeZoneStruct, PidLidTimeZoneDescription, PidLidLocation,
     PidLidAppointmentStateFlags, PidLidAppointmentColor, PidLidResponseStatus,
+    PidLidAppointmentStartWhole, PidLidAppointmentEndWhole, PidLidAppointmentReplyName,
+    PidLidAppointmentReplyTime,
 )
 
 try:
@@ -45,12 +50,6 @@ except ImportError: # pragma: no cover
 
 from . import timezone as _timezone
 
-# TODO use pidlids instead!
-ALL_DAY_NAME = (PSETID_Appointment, MNID_ID, 0x8215)
-START_NAME = (PSETID_Appointment, MNID_ID, 33293)
-END_NAME = (PSETID_Appointment, MNID_ID, 33294)
-RECURRING_NAME = (PSETID_Appointment, MNID_ID, 33315)
-BUSYSTATUS = (PSETID_Appointment, MNID_ID, 33285)
 
 class Appointment(object):
     """Appointment mixin class
@@ -62,7 +61,7 @@ class Appointment(object):
     @property
     def all_day(self):
         """Appointment is all-day."""
-        proptag = self.store._name_id(ALL_DAY_NAME) | PT_BOOLEAN
+        proptag = self.store._pidlid_proptag(PidLidAppointmentSubType)
         return self._get_fast(proptag)
 
     @all_day.setter
@@ -91,8 +90,7 @@ class Appointment(object):
     @property
     def start(self):
         """Appointment start."""
-        proptag = self.store._name_id(START_NAME) | PT_SYSTIME
-        return self._get_fast(proptag)
+        return self._get_fast(self.store._pidlid_proptag(PidLidAppointmentStartWhole))
 
     @start.setter
     def start(self, val): # TODO update/invalidate cache
@@ -105,8 +103,7 @@ class Appointment(object):
     @property
     def end(self):
         """Appointment end."""
-        proptag = self.store._name_id(END_NAME) | PT_SYSTIME
-        return self._get_fast(proptag)
+        return self._get_fast(self.store._pidlid_proptag(PidLidAppointmentEndWhole))
 
     @end.setter
     def end(self, val): # TODO update/invalidate cache
@@ -128,8 +125,7 @@ class Appointment(object):
     @property
     def recurring(self):
         """Appointment is recurring."""
-        proptag = self.store._name_id(RECURRING_NAME) | PT_BOOLEAN
-        return self._get_fast(proptag)
+        return self._get_fast(self.store._pidlid_proptag(PidLidRecurring))
 
     @recurring.setter
     def recurring(self, value): # TODO update/invalidate cache
@@ -140,7 +136,7 @@ class Appointment(object):
 
     @property
     def busystatus(self): # TODO deprecate and use busy_status instead?
-        proptag = self.store._name_id(BUSYSTATUS) | PT_LONG
+        proptag = self.store._pidlid_proptag(PidLidBusyStatus)
         return FB_STATUS.get(self._get_fast(proptag))
 
     @busystatus.setter
@@ -151,7 +147,6 @@ class Appointment(object):
         except KeyError:
             raise ArgumentError('invalid busy status: %s' % val)
 
-
     @property
     def recurrence(self):
         """Appointment :class:`recurrence <Recurrence>`."""
@@ -160,7 +155,8 @@ class Appointment(object):
         except NotFoundError:
             pass
 
-    def occurrences(self, start=None, end=None):
+    def occurrences(self, start=None, end=None, page_start=None,
+                    page_limit=None, order=None):
         """Appointment :class:`occurrences <Occurrence>` (expanding
         recurring appointments).
 
@@ -168,10 +164,17 @@ class Appointment(object):
         :param end: end at given date (optional)
         """
 
+        pos = 0
+        count = 0
         recurrence = self.recurrence
         if self.recurring and recurrence:
-            for occ in self.recurrence.occurrences(start=start, end=end):
-                yield occ
+            for occurrence in self.recurrence.occurrences(start=start, end=end):
+                if page_start is None or pos >= page_start:
+                    yield occurrence
+                    count += 1
+                if page_limit is not None and count >= page_limit:
+                    break
+                pos += 1
         else:
             if (not start or self.end > start) and \
                (not end or self.start < end):
@@ -184,7 +187,6 @@ class Appointment(object):
         if recurrence and not self.recurring:
             self.server.log.warn("Item '%s' has a recurrence but is not recurring", self.entryid)
 
-
     def occurrence(self, id_=None):
         if self.recurring:
             return self.recurrence.occurrence(id_)
@@ -217,10 +219,13 @@ class Appointment(object):
 
     # TODO rrule setter!
 
-    # TODO merge with item.recipients?
     def attendees(self):
         """Appointment :class:`attendees <Attendee>`."""
-        for row in self.table(PR_MESSAGE_RECIPIENTS):
+
+        # Filter out organizer from all recipients
+        restriction = Restriction(SOrRestriction([SNotRestriction(SExistRestriction(PR_RECIPIENT_FLAGS)),
+                                                  SBitMaskRestriction(BMR_EQZ, PR_RECIPIENT_FLAGS, recipOrganizer)]))
+        for row in self.table(PR_MESSAGE_RECIPIENTS, restriction=restriction):
             yield Attendee(self.server, row)
 
     def create_attendee(self, type_, address):
@@ -245,8 +250,8 @@ class Appointment(object):
         names.append([
             SPropValue(PR_RECIPIENT_TYPE, reciptype),
             SPropValue(PR_DISPLAY_NAME_W, pr_dispname),
-            SPropValue(PR_ADDRTYPE_W, _unicode(pr_addrtype)),
-            SPropValue(PR_EMAIL_ADDRESS_W, _unicode(pr_email)),
+            SPropValue(PR_ADDRTYPE_W, str(pr_addrtype)),
+            SPropValue(PR_EMAIL_ADDRESS_W, str(pr_email)),
             SPropValue(PR_ENTRYID, pr_entryid),
         ])
         self.mapiobj.ModifyRecipients(MODRECIP_ADD, names)
@@ -268,6 +273,14 @@ class Appointment(object):
         except NotFoundError:
             return 'None'
 
+    @response_status.setter
+    def response_status(self, val):
+        try:
+            # props are identical
+            self.create_prop('appointment:33304', STATUS_RESPONSE[val], PT_LONG)
+        except KeyError:
+            raise ArgumentError('invalid response status: %s' % val)
+
     @property
     def icaluid(self):
         """Appointment iCal UID."""
@@ -286,7 +299,7 @@ class Appointment(object):
     @property
     def tzinfo(self):
         """Appointment timezone as datetime compatible tzinfo object."""
-        tzdata = self.get(PidLidTimeZoneStruct)
+        tzdata = self._get_fast(self.store._pidlid_proptag(PidLidTimeZoneStruct))
         if tzdata:
             return _timezone.MAPITimezone(tzdata)
 
@@ -297,21 +310,52 @@ class Appointment(object):
 
     @timezone.setter
     def timezone(self, value):
-        self[PidLidTimeZoneDescription] = _unicode(value)
+        self[PidLidTimeZoneDescription] = str(value)
         self[PidLidTimeZoneStruct] = _timezone._timezone_struct(value)
 
-    def accept(self, comment=None, tentative=False, respond=True):
-        # TODO update appointment itself
+    @property
+    def replytime(self):
+        return self.get(PidLidAppointmentReplyTime)
+
+    @replytime.setter
+    def replytime(self, value):
+        self[PidLidAppointmentReplyTime] = value
+
+    @property
+    def replyname(self):
+        return self.get(PidLidAppointmentReplyName)
+
+    @replyname.setter
+    def replyname(self, value):
+        self[PidLidAppointmentReplyName] = value
+
+    def accept(self, comment=None, tentative=False, respond=True, subject_prefix=None):
+        if tentative:
+            self.busystatus = 'tentative'
+            self.response_status = 'TentativelyAccepted'
+        else:
+            self.busystatus = 'busy'
+            self.response_status = 'Accepted'
+
+        self.replytime = datetime.now()
+        self.replyname = self.store.user.fullname
 
         if respond:
             if tentative:
+                if not subject_prefix:
+                    subject_prefix = 'Tentatively acccepted'
                 message_class = 'IPM.Schedule.Meeting.Resp.Tent'
+                self._respond(subject_prefix, message_class, comment)
             else:
+                if not subject_prefix:
+                    subject_prefix = 'Accept'
                 message_class = 'IPM.Schedule.Meeting.Resp.Pos'
-            self._respond('Accepted', message_class, comment)
+                self._respond(subject_prefix, message_class, comment)
 
     def decline(self, comment=None, respond=True):
-        # TODO update appointment itself
+        self.response_status = 'Declined'
+        self.replytime = datetime.now()
+        self.replyname = self.store.user.fullname
 
         if respond:
             message_class = 'IPM.Schedule.Meeting.Resp.Neg'
@@ -325,9 +369,18 @@ class Appointment(object):
         response.subject = subject_prefix + ': ' + self.subject
         if comment:
             response.text = comment
-        response.to = self.server.user(email=self.from_.email) # TODO
+
+        if not self.from_.email:
+            self.server.log.debug("Item '%s' has no organiser cannot send meeting request response", self.entryid)
+            return
+
         response.from_ = self.store.user # TODO slow?
 
+        try:
+            response.to = self.server.user(email=self.from_.email)
+        except NotFoundError:
+            response.to = self.from_.email
+
         response.send()
 
     def cancel(self):
@@ -355,7 +408,7 @@ class Appointment(object):
     @property
     def onlinemeetingurl(self):
         try:
-            return self.prop('public:OnlineMeetingExternalLink').value
+            return self.prop('public:OnlineMeetingExternalLink', proptype=PT_UNICODE).value
         except NotFoundError:
             return ''
 
@@ -363,4 +416,4 @@ class Appointment(object):
     def onlinemeetingurl(self, value):
         if not isinstance(value, str):
             raise ArgumentError('meeting url must be a string')
-        self.create_prop('public:OnlineMeetingExternalLink', proptype=PT_UNICODE, value=value)
+        self.create_prop('public:OnlineMeetingExternalLink', value, proptype=PT_UNICODE)
