@@ -8,10 +8,7 @@ Copyright 2016 - 2019 Kopano and its licensors (see LICENSE file)
 
 import contextlib
 import logging.handlers
-try:
-    from Queue import Empty
-except ImportError:
-    from queue import Empty
+from queue import Empty
 import sys
 import threading
 import traceback
@@ -83,8 +80,7 @@ def logger(service, options=None, stdout=False, config=None, name=''):
         ch = logging.StreamHandler(sys.stdout)
         ch.setLevel(log_level)
         ch.setFormatter(formatter)
-        if stdout or (options and options.foreground and \
-                      (log_method, log_file) != ('file', '-')):
+        if stdout or ((log_method, log_file) != ('file', '-')):
             logger.addHandler(ch)
     logger.setLevel(log_level)
     return logger
