@@ -51,7 +51,6 @@ from .defs import (
     ASF_MEETING, ASF_RECEIVED, ASF_CANCELED
 )
 
-from .compat import repr as _repr
 from .errors import Error
 from .restriction import Restriction
 
@@ -61,7 +60,6 @@ except ImportError: # pragma: no cover
     _utils = sys.modules[__package__ + '.utils']
 
 from . import property_ as _prop
-from . import timezone as _timezone
 
 # TODO move all pidlids into separate definition file, plus short description
 # of their meanings
@@ -133,7 +131,7 @@ def _organizer_props(cal_item, item):
 
     table = cal_item.mapiobj.OpenProperty(
         PR_MESSAGE_RECIPIENTS, IID_IMAPITable, MAPI_UNICODE, 0)
-    for row in table.QueryRows(-1, 0):
+    for row in table.QueryRows(2147483647, 0):
         recipient_flags = PpropFindProp(row, PR_RECIPIENT_FLAGS)
         if (recipient_flags and \
             recipient_flags.Value == (recipOrganizer | recipSendable)):
@@ -232,7 +230,7 @@ def _create_meetingrequest(cal_item, item, basedate=None):
         PR_MESSAGE_RECIPIENTS, IID_IMAPITable, MAPI_UNICODE, 0)
     table.SetColumns(RECIP_PROPS, 0)
     orgs = []
-    for row in table.QueryRows(-1,0):
+    for row in table.QueryRows(2147483647, 0):
         recipient_flags = PpropFindProp(row, PR_RECIPIENT_FLAGS)
         if recipient_flags and recipient_flags.Value & recipOrganizer:
             orgs.append(row)
@@ -424,7 +422,7 @@ class MeetingRequest(object):
             table = cal_item.mapiobj.OpenProperty(
                 PR_MESSAGE_RECIPIENTS, IID_IMAPITable, MAPI_UNICODE, 0)
             table.SetColumns(RECIP_PROPS, 0)
-            rows = table.QueryRows(-1, 0)
+            rows = table.QueryRows(2147483647, 0)
             # TODO php-compat: php checks 'move' flag, should we
             if tentative:
                 cal_item.mapiobj.ModifyRecipients(MODRECIP_REMOVE,
@@ -528,7 +526,7 @@ class MeetingRequest(object):
                 table = cal_item.mapiobj.OpenProperty(
                     PR_MESSAGE_RECIPIENTS, IID_IMAPITable, MAPI_UNICODE, 0)
                 table.SetColumns(RECIP_PROPS, 0)
-                rows = table.QueryRows(-1, 0)
+                rows = table.QueryRows(2147483647, 0)
                 cal_item.mapiobj.ModifyRecipients(MODRECIP_MODIFY, rows)
                 _utils._save(cal_item.mapiobj)
 
@@ -668,7 +666,7 @@ class MeetingRequest(object):
         # TODO things seem to get lost without this
         table.SetColumns(RECIP_PROPS, 0)
 
-        rows = table.QueryRows(-1, 0)
+        rows = table.QueryRows(2147483647, 0)
         for row in rows:
             if self._compare_ab_entryids(
                 PpropFindProp(row, PR_ENTRYID).Value,
@@ -747,4 +745,4 @@ class MeetingRequest(object):
         return 'MeetingRequest()'
 
     def __repr__(self):
-        return _repr(self)
+        return self.__unicode__()
