@@ -15,7 +15,7 @@ import dateutil.parser
 queries into MAPI restrictions, as used when for example searching
 for specific mails or users.
 
-To achive this, it uses a hand-written parser, using the building
+To achieve this, it uses a hand-written parser, using the building
 blocks in parse.py.
 """
 
@@ -45,7 +45,6 @@ from MAPI.Defs import PROP_TYPE
 from .errors import ArgumentError
 from .restriction import Restriction
 from .defs import PSETID_Address, PS_PUBLIC_STRINGS
-from .compat import fake_unicode as _unicode
 
 from .parse import (
     ParserInput, Parser, Char, CharSet, ZeroOrMore, OneOrMore, Sequence,
@@ -55,10 +54,10 @@ from .parse import (
 # TODO such grouping: 'subject:(fresh exciting)'
 # TODO Regex: avoid substr
 # TODO OneOrMore(regex) not needed?
-# TODO operator associativity/precedence (eg 'NOT a AND b'), check MSG
+# TODO operator associativity/precedence (e.g. 'NOT a AND b'), check MSG
 # TODO escaping double quotes
 # TODO asterisk not implicit for phrases
-# TODO relative dates rel. to timezone (eg "received:today")
+# TODO relative dates rel. to timezone (e.g. "received:today")
 # TODO graph does not support 'size>"10 KB" and such? we now roll our own
 # TODO email matching on to/cc/bcc (PR_SEARCH_KEY/PR_EMAIL_ADDRESS?)
 # TODO sender:user2@domain.com OR category:blue doesn't work, even if they
@@ -465,7 +464,7 @@ def _build_parser():
 _PARSER = _build_parser()
 
 def _query_to_restriction(query, type_, store):
-    query = _unicode(query)
+    query = str(query)
     try:
         ast = _PARSER.parse(ParserInput(query)).value
         return Restriction(ast.restriction(type_, store))
