@@ -17,11 +17,12 @@ import socket
 import sys
 import warnings
 
+from urllib.parse import urlparse
+
 from MAPI import (
     MAPI_UNICODE, MDB_WRITE, RELOP_EQ, MAPI_MAILUSER, TBL_BATCH,
-    ECSTORE_TYPE_PRIVATE, MAPI_DEFERRED_ERRORS, DT_REMOTE_MAILUSER,
-    RELOP_NE, FL_FULLSTRING, FL_IGNORECASE, BOOKMARK_BEGINNING,
-    EC_OVERRIDE_HOMESERVER, WrapStoreEntryID
+    ECSTORE_TYPE_PRIVATE, DT_REMOTE_MAILUSER, RELOP_NE, FL_FULLSTRING,
+    FL_IGNORECASE, BOOKMARK_BEGINNING, EC_OVERRIDE_HOMESERVER, WrapStoreEntryID
 )
 from MAPI.Util import (
     GetDefaultStore, OpenECSession
@@ -65,8 +66,8 @@ from .group import Group
 from .query import _query_to_restriction
 
 from .compat import (
-    repr as _repr, benc as _benc,
-    bdec as _bdec, fake_unicode as _unicode,
+    benc as _benc,
+    bdec as _bdec
 )
 
 try:
@@ -192,8 +193,8 @@ class Server(object):
     def __init__(self, options=None, config=None, sslkey_file=None,
             sslkey_pass=None, server_socket=None, auth_user=None,
             auth_pass=None, log=None, service=None, mapisession=None,
-            parse_args=True, notifications=False, store_cache=True,
-            oidc=False, _skip_check=False):
+            parse_args=False, notifications=False, store_cache=True,
+            oidc=False, _skip_check=True):
         """
         Create Server instance.
 
@@ -297,7 +298,7 @@ class Server(object):
             if not notifications:
                 flags |= EC_PROFILE_FLAGS_NO_NOTIFICATIONS
 
-            # Username and password was supplied, so let us do verfication
+            # Username and password was supplied, so let us do verification
             # (OpenECSession will not check password unless this parameter
             # is provided)
             if self.auth_user and self.auth_pass:
@@ -506,13 +507,22 @@ password incorrect')
         if _company and _company.name != 'Default':
             htable = gab.GetHierarchyTable(0)
             htable.SetColumns([PR_ENTRYID], TBL_BATCH)
-            htable.FindRow(SContentRestriction(
-                    FL_FULLSTRING | FL_IGNORECASE,
-                    PR_DISPLAY_NAME_W,
-                    SPropValue(PR_DISPLAY_NAME_W, _company.name)),
-                BOOKMARK_BEGINNING, 0)
-            row = htable.QueryRows(1, 0)[0]
-            container = gab.OpenEntry(row[0].Value, None, 0)
+            # TODO(longsleep): Find a way to avoid finding the limited table,
+            # if the gab is itself already limited to the same.
+            try:
+                htable.FindRow(SContentRestriction(
+                        FL_FULLSTRING | FL_IGNORECASE,
+                        PR_DISPLAY_NAME_W,
+                        SPropValue(PR_DISPLAY_NAME_W, _company.name)),
+                    BOOKMARK_BEGINNING, 0)
+            except MAPIErrorNotFound:
+                # If not, found we do not have permission to access that row. and
+                # instead fall back to the gab and let it handle access and
+                # limits based on user authentication.
+                container = gab
+            else:
+                row = htable.QueryRows(1, 0)[0]
+                container = gab.OpenEntry(row[0].Value, None, 0)
         else:
             container = gab
 
@@ -598,16 +608,16 @@ password incorrect')
         :param fullname: User full name (optional)
         :param create_store: Should a store be created (default True)
         """
-        fullname = _unicode(fullname or name or '')
-        name = _unicode(name)
+        fullname = str(fullname or name or '')
+        name = str(name)
         if email:
-            email = _unicode(email)
+            email = str(email)
         else:
             email = '%s@%s' % (name, socket.gethostname())
         if password:
-            password = _unicode(password)
+            password = str(password)
         if company:
-            company = _unicode(company)
+            company = str(company)
         if company and company != 'Default':
             self.sa.CreateUser(ECUSER('%s@%s' % (name, company), password,
                 email, fullname), MAPI_UNICODE)
@@ -715,7 +725,7 @@ password incorrect')
 
         :param name: Company name
         """
-        name = _unicode(name)
+        name = str(name)
         try:
             self.sa.CreateCompany(ECCOMPANY(name, None), MAPI_UNICODE)
         except MAPIErrorCollision:
@@ -738,7 +748,7 @@ password incorrect')
         table.SetColumns([PR_ENTRYID], 0)
         table.Restrict(SPropertyRestriction(RELOP_EQ, PR_STORE_RECORD_KEY,
             SPropValue(PR_STORE_RECORD_KEY, storeid)), TBL_BATCH)
-        for row in table.QueryRows(-1, 0):
+        for row in table.QueryRows(2147483647, 0):
             return self._store2(row[0].Value)
         raise NotFoundError("no such store: '%s'" % guid)
 
@@ -787,9 +797,9 @@ password incorrect')
         :param hidden: hide the group (optional)
         :param groupid: the id of the group (optional)
         """
-        name = _unicode(name) # TODO: fullname/email unicode?
-        email = _unicode(email)
-        fullname = _unicode(fullname)
+        name = str(name) # TODO: fullname/email unicode?
+        email = str(email)
+        fullname = str(fullname)
         try:
             self.sa.CreateGroup(ECGROUP(name, fullname, email, int(hidden),
                 groupid), MAPI_UNICODE)
@@ -845,7 +855,7 @@ password incorrect')
         :param guid: Store GUID (optional)
         :param entryid: Store entryid (optional)
         """
-        if isinstance(guid, str) and _unicode(guid).split('@')[0] == 'public':
+        if isinstance(guid, str) and str(guid).split('@')[0] == 'public':
             return self._pubstore(guid)
         else:
             return _store.Store(guid=guid, entryid=entryid, server=self)
@@ -877,13 +887,27 @@ password incorrect')
 
         table = self.ems.GetMailboxTable(None, 0)
         table.SetColumns([PR_DISPLAY_NAME_W, PR_ENTRYID], 0)
-        for row in table.QueryRows(-1, 0):
+        for row in table.QueryRows(2147483647, 0):
             store = _store.Store(
                 mapiobj=self._store2(row[1].Value),server=self)
             if not system and store.user and store.user.name == 'SYSTEM':
                 continue
             yield store
 
+    def _get_server_port(self):
+        '''Parse server_socket and return None or the server port used'''
+
+        if self.server_socket == 'default:':
+            return
+
+        if self.server_socket.startswith('file://'):
+            return
+
+        parsed = urlparse(self.server_socket)
+        if not parsed:
+            return
+        return parsed.port
+
     def create_store(self, user, _msr=False):
         """Create store for :class:`User`.
 
@@ -900,11 +924,17 @@ password incorrect')
             except MAPIErrorCollision:
                 raise DuplicateError("user '%s' already has an associated \
 store (unhook first?)" % user.name)
+            # Parse the server, fallback to 237 for now
+            server_port = self._get_server_port()
+            if not server_port:
+                # TODO: raise exception?
+                server_port = 237
+
             store_entryid = \
                 WrapStoreEntryID(0, b'zarafa6client.dll',storeid[:-4]) + \
                 b'https://' + \
                 codecs.encode(self.name, 'utf-8') + \
-                b':237\x00'
+                b':' + str(server_port).encode('utf-8') + b'\x00'
             # multi-server flag
             store_entryid = \
                 store_entryid[:66] + \
@@ -1092,4 +1122,4 @@ multi-tenant setup')
         return 'Server(%s)' % self.server_socket
 
     def __repr__(self):
-        return _repr(self)
+        return self.__unicode__()
