@@ -62,7 +62,7 @@ from .properties import Properties
 from .autoaccept import AutoAccept
 from .autoprocess import AutoProcess
 from .outofoffice import OutOfOffice
-from .property_ import Property
+from .property_ import Property, _name_to_proptag
 from .delegation import Delegation
 from .permission import Permission, _permissions_dumps, _permissions_loads
 from .freebusy import FreeBusy
@@ -72,7 +72,7 @@ from .restriction import Restriction
 from . import notification as _notification
 
 from .compat import (
-    bdec as _bdec, benc as _benc, fake_unicode as _unicode,
+    bdec as _bdec, benc as _benc
 )
 
 from . import server as _server
@@ -142,6 +142,7 @@ class Store(Properties):
         self.__root = None
 
         self._name_id_cache = {}
+        self._pidlid_cache = {}
 
     @property
     def _root(self):
@@ -201,8 +202,12 @@ class Store(Properties):
                 value = 5 * [b'']
             value[idx] = _bdec(folder.entryid)
             _root.SetProps([SPropValue(proptag, value)])
+            if self.inbox:
+                self.inbox.mapiobj.SetProps([SPropValue(proptag, value)])
         else:
             _root.SetProps([SPropValue(proptag, _bdec(folder.entryid))])
+            if self.inbox:
+                self.inbox.mapiobj.SetProps([SPropValue(proptag, _bdec(folder.entryid))])
         _utils._save(self._root)
 
         if container_class:
@@ -595,24 +600,39 @@ class Store(Properties):
             for folder in self.subtree.folders(recurse=recurse, **kwargs):
                 yield folder
 
-    # TODO replace by store.folders(type='contacts') etc
     def mail_folders(self, **kwargs):
-        # TODO restriction
-        for folder in self.folders():
-            if folder.type_ == 'mail':
+        # Mail folders are a fixed set of folders which all can contain mail
+        # items, plus any other customly created folder of container class
+        # IPF.Note.
+        static = {}
+        for n in ('inbox', 'outbox', 'sentmail', 'wastebasket', 'drafts', 'junk'):
+            f = getattr(self, n)
+            if f is not None:
+                static[f.entryid] = True
+                yield f
+        # Find additional folders using a restrictions.
+        restriction = Restriction(SPropertyRestriction(
+            RELOP_EQ, PR_CONTAINER_CLASS_W,
+            SPropValue(PR_CONTAINER_CLASS_W, 'IPF.Note')
+        ))
+        for folder in self.folders(restriction=restriction, **kwargs):
+            # Yield additional folders, filtering by the fixed ones.
+            if folder.entryid not in static:
                 yield folder
 
     def contact_folders(self, **kwargs):
-        # TODO restriction
-        for folder in self.folders():
-            if folder.type_ == 'contacts':
-                yield folder
+        restriction = Restriction(SPropertyRestriction(
+            RELOP_EQ, PR_CONTAINER_CLASS_W,
+            SPropValue(PR_CONTAINER_CLASS_W, 'IPF.Contact')
+        ))
+        return self.folders(restriction=restriction, **kwargs)
 
     def calendars(self, **kwargs):
-        # TODO restriction
-        for folder in self.folders():
-            if folder.type_ == 'calendar':
-                yield folder
+        restriction = Restriction(SPropertyRestriction(
+            RELOP_EQ, PR_CONTAINER_CLASS_W,
+            SPropValue(PR_CONTAINER_CLASS_W, 'IPF.Appointment')
+        ))
+        return self.folders(restriction=restriction, **kwargs)
 
     # TODO store.findroot.create_folder()?
     def create_searchfolder(self, text=None):
@@ -657,7 +677,7 @@ class Store(Properties):
 
         :param name: The config item name
         """
-        name = _unicode(name)
+        name = str(name)
         table = self.subtree.mapiobj.GetContentsTable(
             MAPI_DEFERRED_ERRORS | MAPI_ASSOCIATED)
         table.Restrict(SPropertyRestriction(
@@ -843,6 +863,9 @@ class Store(Properties):
             except MAPIErrorNotFound:
                 raise NotFoundError("no user found with userid '%s'" % \
                     _benc(entryid))
+            except MAPIErrorInvalidEntryid:
+                self.server.log.warning("invalid delegation entryid: '%s'", _benc(entryid))
+                continue
             yield Delegation(self, self.server.user(username))
 
     def delegation(self, user, create=False, see_private=False):
@@ -1055,7 +1078,7 @@ class Store(Properties):
             SPropValue(PR_MESSAGE_CLASS_W, 'IPM.Microsoft.WunderBar.SFInfo')),
             TBL_BATCH)
 
-        for row in table.QueryRows(-1, 0):
+        for row in table.QueryRows(2147483647, 0):
             try:
                 yield guid_folder[row[1].Value]
             except KeyError:
@@ -1110,6 +1133,7 @@ class Store(Properties):
         return FreeBusy(self)
 
     def _name_id(self, name_tuple):
+        # TODO: use _pidlid_proptag everywhere
         id_ = self._name_id_cache.get(name_tuple)
         if id_ is None:
             named_props = [MAPINAMEID(*name_tuple)]
@@ -1119,6 +1143,13 @@ class Store(Properties):
             self._name_id_cache[name_tuple] = id_
         return id_
 
+    def _pidlid_proptag(self, pidlid):
+        id_ = self._pidlid_cache.get(pidlid)
+        if id_ is None:
+            id_ = _name_to_proptag(pidlid, self.mapiobj)[0]
+            self._pidlid_cache[pidlid] = id_
+        return id_
+
     def __eq__(self, s): # TODO check same server?
         if isinstance(s, Store):
             return self.guid == s.guid
