@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/local/bin/python3.7
 # SPDX-License-Identifier: AGPL-3.0-only
 from .version import __version__
 
@@ -266,7 +266,9 @@ class BackupWorker(kopano.Worker):
         open(data_path+'/folder', 'wb').write(dump_props(folder.props(), stats, self.log))
         if not options.skip_meta:
             open(data_path+'/acl', 'wb').write(folder.permissions_dumps(stats=stats))
-            open(data_path+'/rules', 'wb').write(folder.rules_dumps(stats=stats))
+            rules = folder.rules_dumps(stats=stats)
+            if rules:
+                open(data_path+'/rules', 'wb').write(rules)
         if options.only_meta:
             return
 
@@ -423,8 +425,10 @@ class Service(kopano.Service):
 
         try:
             if self.options.users:
+                username = self.options.users[0]
                 store = self._store(self.options.users[0])
             elif self.options.stores:
+                username = self.options.stores[0]
                 store = self.server.store(self.options.stores[0])
             else:
                 store = self._store(username)
@@ -526,7 +530,8 @@ class Service(kopano.Service):
             self.log.info('restoring metadata')
             for (folder, fpath) in meta_folders:
                 folder.permissions_loads(open(fpath+'/acl', 'rb').read(), stats=stats)
-                folder.rules_loads(open(fpath+'/rules', 'rb').read(), stats=stats)
+                if os.path.exists(fpath+'/rules'):
+                    folder.rules_loads(open(fpath+'/rules', 'rb').read(), stats=stats)
 
         # restore store-level metadata (webapp/mapi settings)
         if user and not (self.options.folders or self.options.restore_root or self.options.skip_meta or self.options.sourcekeys):
@@ -708,7 +713,7 @@ class Service(kopano.Service):
         existing = {}
         table = folder.mapiobj.GetContentsTable(0)
         table.SetColumns([PR_SOURCE_KEY, PR_EC_BACKUP_SOURCE_KEY, PR_ENTRYID], 0)
-        for row in table.QueryRows(-1, 0):
+        for row in table.QueryRows(2147483647, 0):
             if PROP_TYPE(row[1].ulPropTag) != PT_ERROR:
                 existing[_hex(row[1].Value)] = _hex(row[2].Value)
             else:
@@ -902,7 +907,6 @@ def dump_props(props, stats, log):
         data = dict((prop.proptag, prop.mapiobj.Value) for prop in props)
     return pickle_dumps(data)
 
-
 def main():
     # select common options
     parser = kopano.parser('CKQSufwUPcslObeV', usage='kopano-backup [PATH] [options]')
