@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/local/bin/python3.7
 # SPDX-License-Identifier: AGPL-3.0-or-later
 from .version import __version__
 
@@ -12,7 +12,8 @@ import sys
 from collections import defaultdict
 
 from MAPI.Util import *
-from MAPI.Tags import (PS_COMMON, PS_ARCHIVE,
+from MAPI.Struct import MAPIErrorNetworkError
+from MAPI.Tags import (PS_COMMON, PS_ARCHIVE, PS_ADDRESS,
                        PR_SENDER_EMAIL_ADDRESS_W, PR_SENDER_ENTRYID,
                        PR_SENDER_NAME_W, PR_SENDER_ADDRTYPE_W,
                        PR_SENDER_SEARCH_KEY,
@@ -30,7 +31,13 @@ from kopano import log_exc
 
 from kopano.pidlid import (
     PidLidDistributionListMembers,
-    PidLidDistributionListOneOffMembers
+    PidLidDistributionListOneOffMembers,
+    PidLidEmail1AddressType,
+    PidLidEmail2AddressType,
+    PidLidEmail3AddressType,
+    PidLidEmail1EmailAddress,
+    PidLidEmail2EmailAddress,
+    PidLidEmail3EmailAddress,
 )
 
 from . import pst
@@ -81,8 +88,41 @@ RECEIVED_REPR_PROPS = {
     'smtp': pst.PropIdEnum.PidTagReceivedRepresentingSmtpAddress,
 }
 
+# Contact email address definitions
+CONTACT_ADDRTYPES = [int(pidlid.split(':')[2], 16) for pidlid in [PidLidEmail1AddressType, PidLidEmail2AddressType, PidLidEmail3AddressType]]
+CONTACT_EMAILS = [int(pidlid.split(':')[2], 16) for pidlid in [PidLidEmail1EmailAddress, PidLidEmail2EmailAddress, PidLidEmail3EmailAddress]]
+CONTACT_ORIG_DISPLAYNAME = [0x8084, 0x8094, 0x80A4]
+
+CONTACT_EMAIL_ADDRESS1 = {
+    'addrtype': CONTACT_ADDRTYPES[0],
+    'email': CONTACT_EMAILS[0],
+    'origdisplayname': CONTACT_ORIG_DISPLAYNAME[0],
+}
+
+CONTACT_ADDRTYPE_MAP = {
+    CONTACT_ADDRTYPES[0]: {
+        'email': CONTACT_EMAILS[0],
+        'origdisplayname': CONTACT_ORIG_DISPLAYNAME[0],
+    },
+    CONTACT_ADDRTYPES[1]: {
+        'email': CONTACT_EMAILS[1],
+        'origdisplayname': CONTACT_ORIG_DISPLAYNAME[1],
+    },
+    CONTACT_ADDRTYPES[2]: {
+        'email': CONTACT_EMAILS[2],
+        'origdisplayname': CONTACT_ORIG_DISPLAYNAME[2],
+    },
+}
+
+CONTACT_EMAIL_ADDRESS3 = {
+    'addrtype': CONTACT_ADDRTYPES[2],
+    'email': CONTACT_EMAILS[2],
+    'origdisplayname': CONTACT_ORIG_DISPLAYNAME[2],
+}
+
 EMAIL_RECIP_PROPS = [SENDER_PROPS, SENT_REPRESENTING_PROPS, RECEIVED_PROPS, RECEIVED_REPR_PROPS]
 
+
 def recip_prop(propid, value):
     # PST not generated with full unicode?
     if isinstance(value, bytes):
@@ -103,6 +143,8 @@ class Service(kopano.Service):
         attach_method = subnode_nid = None
         reminder_in_past = False
         reminder_set_id = None
+        contact_email_props = {}
+
         for k, v in parent.pc.props.items():
             propid, proptype, value = k, v.wPropType, v.value
 
@@ -125,6 +167,9 @@ class Service(kopano.Service):
                             reminder_in_past = True
                     elif nameid[2] == REMINDER_SET_ID:
                         reminder_set_id = propid
+                elif nameid[0] == PS_ADDRESS:
+                    if nameid[2] in CONTACT_ADDRTYPES and value and value == 'EX':
+                        contact_email_props[nameid[2]] = True
 
             if propid == (PR_SUBJECT_W>>16) and value and ord(value[0]) == 0x01:
                 value = value[2:] # \x01 plus another char indicates normalized-subject-prefix-length
@@ -159,9 +204,43 @@ class Service(kopano.Service):
             if addrtype and addrtype == 'EX':
                 proplist.extend(self.convert_exchange_recipient(parent, prop_dict))
 
+        if contact_email_props:
+            proplist.extend(self.convert_exchange_contact(contact_email_props, mapiobj, parent))
+
         mapiobj.SetProps(proplist)
         mapiobj.SaveChanges(KEEP_OPEN_READWRITE)
 
+
+    def convert_exchange_contact(self, contact_email_props, mapiobj, parent):
+        props = []
+
+        for addrtype in contact_email_props:
+            emailproptag = None
+            newemail = None
+            email = CONTACT_ADDRTYPE_MAP[addrtype]['email']
+            origdisplayname = CONTACT_ADDRTYPE_MAP[addrtype]['origdisplayname']
+
+            for k, v in parent.pc.props.items():
+                propid, proptype, value = k, v.wPropType, v.value
+                nameid = self.propid_nameid.get(propid)
+                if not nameid:
+                    continue
+
+                if nameid[0] != PS_ADDRESS:
+                    continue
+
+                if nameid[2] == origdisplayname:
+                    newemail = value
+
+                if nameid[2] == email:
+                    propid = PROP_ID(mapiobj.GetIDsFromNames([MAPINAMEID(*nameid)], MAPI_CREATE)[0])
+                    emailproptag = PROP_TAG(proptype, propid)
+
+            if newemail and emailproptag:
+                props.append(SPropValue(emailproptag, newemail))
+
+        return props
+
     def convert_exchange_recipient(self, parent, convertprops):
         props = []
         email = parent.pc.getval(convertprops['smtp'])
@@ -173,6 +252,7 @@ class Service(kopano.Service):
                 legacyExchangeDN = legacyExchangeDN.lower()
                 try:
                     email = self.mapping[legacyExchangeDN]
+                    self.log.debug('found legacyExchangeDN: \'%s\' in mapping', legacyExchangeDN)
                 except KeyError:
                     if legacyExchangeDN not in self.nomapping:
                         self.log.warning('legacyExchangeDN: \'%s\' was not found in mapping', legacyExchangeDN)
@@ -267,7 +347,7 @@ class Service(kopano.Service):
                     props.append(recip_prop(PROP_ID(PR_ADDRTYPE), u'SMTP'))
                     props.append(recip_prop(PROP_ID(PR_EMAIL_ADDRESS), email))
                 else:
-                    self.log.warning("no email address for recipient '%s'" % r.DisplayName or '')
+                    self.log.warning("no email address for recipient '%s'", r.DisplayName or '')
 
             recipients.append(props)
         mapiobj.ModifyRecipients(0, recipients)
@@ -301,12 +381,17 @@ class Service(kopano.Service):
                 self.log.info("importing folder '%s'", path)
                 if self.options.import_root:
                     path = self.options.import_root + '/' + path
-
-                folder2 = store.folder(path, create=True)
-                if self.options.clean_folders:
-                    folder2.empty()
-                if folder.ContainerClass:
-                    folder2.container_class = folder.ContainerClass
+                while True:
+                    try:
+                        folder2 = store.folder(path, create=True)
+                        if self.options.clean_folders:
+                            folder2.empty()
+                        if folder.ContainerClass:
+                            folder2.container_class = folder.ContainerClass
+                        break
+                    except MAPIErrorNetworkError as e:
+                        self.log.warning("%s: Connection to server lost, retrying in 5 sec", e)
+                        time.sleep(5)
 
                 if import_nids:
                     for nid in import_nids:
@@ -332,13 +417,20 @@ class Service(kopano.Service):
             type_ = 'item'
 
         with log_exc(self.log, self.stats):
-            self.log.debug("importing %s '%s' (NID=%d)" % (type_, rev_cp1252(message.Subject or ''), message.nid.nid))
-            message2 = folder2.create_item(save=False)
-            self.entryid_map[message.EntryId] = message2.entryid
-            self.import_attachments(message, message2.mapiobj)
-            self.import_recipients(message, message2.mapiobj)
-            self.import_props(message, message2.mapiobj)
-            self.stats['messages'] += 1
+            while True:
+                try:
+                    self.log.debug("importing %s '%s' (NID=%d)", type_, rev_cp1252(message.Subject or ''), message.nid.nid)
+                    message2 = folder2.create_item(save=False)
+                    self.entryid_map[message.EntryId] = message2.entryid
+                    self.import_attachments(message, message2.mapiobj)
+                    self.import_recipients(message, message2.mapiobj)
+                    self.import_props(message, message2.mapiobj)
+                    self.stats['messages'] += 1
+                    break
+                except MAPIErrorNetworkError as e:
+                    self.log.warning("{}: Connection to server lost, retrying in 5 sec".format(e))
+                    time.sleep(5)
+
 
     def rewrite_entryids(self, store):
         # distribution lists
