@@ -1,14 +1,22 @@
-#!/usr/local/bin/python3.6
+#!/usr/local/bin/python3.7
 # SPDX-License-Identifier: AGPL-3.0-only
 
 import sys
 import logging
 
-from MAPI.Tags import PR_EC_IMAP_EMAIL_SIZE, PR_EC_IMAP_BODYSTRUCTURE, PR_EC_IMAP_BODY, PR_EC_IMAP_EMAIL, PT_STRING8
-from MAPI.Struct import MAPIErrorNotFound, SNotRestriction, SExistRestriction
+from MAPI import (
+    PT_UNICODE, PT_STRING8,
+)
+from MAPI.Tags import (
+    PR_EC_IMAP_EMAIL_SIZE, PR_EC_IMAP_BODYSTRUCTURE, PR_EC_IMAP_BODYSTRUCTURE_W,
+    PR_EC_IMAP_BODY, PR_EC_IMAP_BODY_W, PR_EC_IMAP_EMAIL,
+)
+from MAPI.Struct import (
+    MAPIErrorNotFound, SNotRestriction, SExistRestriction,
+)
 import inetmapi
 
-from kopano import Restriction, Server, parser
+from kopano import Restriction, server, parser
 
 
 def logger(options):
@@ -22,19 +30,19 @@ def generate_imap_message(item):
 
     item.create_prop(PR_EC_IMAP_EMAIL, eml)
     item.create_prop(PR_EC_IMAP_EMAIL_SIZE, len(eml))
-    item.create_prop(PR_EC_IMAP_BODYSTRUCTURE, bodystructure)
-    item.create_prop(PR_EC_IMAP_BODY, body)
-    item.create_prop('imap:1', envelope, proptype=PT_STRING8)
-    item.mapiobj.SaveChanges(0)
+    item.create_prop(PR_EC_IMAP_BODYSTRUCTURE_W, bodystructure)
+    item.create_prop(PR_EC_IMAP_BODY_W, body)
+    item.create_prop('imap:1', envelope, proptype=PT_UNICODE)
 
+    item.mapiobj.SaveChanges(0)
 
 def main():
     options, _ = parser('ksplu').parse_args()
     log = logger(options)
-    server = Server(options=options, auth_user='SYSTEM', auth_pass='')
+    server = server(options=options, auth_user='SYSTEM', auth_pass='', parse_args=True)
     restriction = Restriction(mapiobj=SNotRestriction(SExistRestriction(PR_EC_IMAP_EMAIL_SIZE)))
 
-    for user in server.users(parse=True):  # XXX multi-company..
+    for user in server.users():  # XXX multi-company..
         # Skip users without IMAP enabled
         if not 'imap' in user.features:
             log.info('Skipping user %s, IMAP disabled', user.name)
